@@ -3,15 +3,10 @@ var ahd__bayer_8c =
     [ "AD", "ahd__bayer_8c.html#a7e98848076c6c8edd529cd3b04beae8d", null ],
     [ "BLUE", "ahd__bayer_8c.html#a79d10e672abb49ad63eeaa8aaef57c38", null ],
     [ "CLAMP", "ahd__bayer_8c.html#aaefe6f014fd5125ca10cc315080003c7", null ],
-    [ "GP_MODULE", "ahd__bayer_8c.html#a42d5a3f91ac1e8add4295c0d288c182f", null ],
     [ "GREEN", "ahd__bayer_8c.html#acfbc006ea433ad708fdee3e82996e721", null ],
     [ "MAX", "ahd__bayer_8c.html#aacc3ee1a7f283f8ef65cea31f4436a95", null ],
     [ "MIN", "ahd__bayer_8c.html#a74e75242132eaabbc1c512488a135926", null ],
     [ "RED", "ahd__bayer_8c.html#a8d23feea868a983c8c2b661e1e16972f", null ],
-    [ "do_green_ctr_row", "ahd__bayer_8c.html#aed00283d19d7e7bf337edf8cf1be0671", null ],
-    [ "do_rb_ctr_row", "ahd__bayer_8c.html#aaf747cdd270a4734d1fef7065ab1932c", null ],
-    [ "dRGB", "ahd__bayer_8c.html#a525d73156d19962521a5d8234e611faa", null ],
-    [ "get_diffs_row2", "ahd__bayer_8c.html#a5315ee11a614ace3579284b0e32f2823", null ],
     [ "gp_ahd_decode", "ahd__bayer_8c.html#a0a10c31feb99742199ca9b8479809ee4", null ],
     [ "gp_ahd_interpolate", "ahd__bayer_8c.html#ad3e98332c40eea761faae753444cfcad", null ]
 ];
\ No newline at end of file
