@@ -14,10 +14,12 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 
+#define _BSD_SOURCE
+
 #include <config.h>
 
 #include <stdlib.h>
@@ -132,18 +134,18 @@ file_list_func (CameraFilesystem *fs, const char *folder, CameraList *list,
 	int num_lo_pics = aox_get_num_lo_pics (camera->pl->info);
 	int num_hi_pics = aox_get_num_hi_pics (camera->pl->info);
 	int n = num_hi_pics + num_lo_pics;
-	char name[n];
+	char name[20];
 	int i;	
 	/* Low-resolution pictures are always downloaded first. We do not know 
 	 * yet how to process them, so they will remain in RAW format. */
 	
 	for (i=0; i< num_lo_pics; i++){
-		sprintf( name, "aox_pic%03i.raw", i+1 );
+		snprintf( name, sizeof(name), "aox_pic%03i.raw", i+1 );
 		gp_list_append(list, name, NULL);	
 	}
 
 	for (i = num_lo_pics; i < n; i++){
-		sprintf( name, "aox_pic%03i.ppm", i+1 );		
+		snprintf( name, sizeof(name), "aox_pic%03i.ppm", i+1 );		
 		gp_list_append(list, name, NULL);	
 	}
     	return GP_OK;
@@ -204,16 +206,18 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 
 	switch (type) {
 	case GP_FILE_TYPE_EXIF:
+		free (data);
 		return (GP_ERROR_FILE_EXISTS);
 
 	case GP_FILE_TYPE_PREVIEW:
 	case GP_FILE_TYPE_NORMAL:
-		if ((w == 320)) {
+		if (w == 320) {
 			gp_file_detect_mime_type (file); /* Detected as "raw"*/
 			gp_file_set_data_and_size (file, (char *)data, len);
 			gp_file_adjust_name_for_mime_type (file);
+			break;
 		}
-		if ((w == 640)){
+		if (w == 640) {
 			/* Stripping useless header */
 			p_data = data + 0x98;
 			/* Picture is mirror-imaged.*/
@@ -231,8 +235,6 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 				p_data[4*i + 1] = p_data[4*i+2];
 				p_data[4*i+2] = temp;
 			}
-			GP_DEBUG("size of data = %i\n", sizeof(data));
-			GP_DEBUG("size of p_data = %i\n", sizeof(p_data));
 			/* And now create a ppm file, with our own header */
 			header_len = snprintf(header, 127, 
 				"P6\n" 
@@ -258,6 +260,7 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
     			gp_file_append (file, header, header_len);
 			gp_file_append (file, (char *)output, 3*w*h);
 		}
+		free (data);
 		free (output);
 		return GP_OK;
 	case GP_FILE_TYPE_RAW:
@@ -266,10 +269,9 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 		gp_file_adjust_name_for_mime_type(file);
 		break;
 	default:
+		free (data);
 		return (GP_ERROR_NOT_SUPPORTED); 	
-
 	}
-
 	return GP_OK;
 }
 
