@@ -12,7 +12,7 @@
  *
  ****************************************************************************/
 
-#define _BSD_SOURCE
+#define _DEFAULT_SOURCE
 
 #include "config.h"
 
