@@ -1,6 +1,6 @@
 /* directory.c
  *
- * Copyright (c) 2001 Lutz Mller <lutz@users.sf.net>
+ * Copyright (c) 2001 Lutz Mueller <lutz@users.sf.net>
  * Copyright (c) 2005 Marcus Meissner <marcus@jet.franken.de>
  * Copyright (c) 2007 Hubert Figuiere <hub@figuiere.net>
  *
@@ -30,7 +30,6 @@
 #include <string.h>
 #include <sys/types.h>
 #include <utime.h>
-#include <unistd.h>
 #ifdef HAVE_SYS_STATVFS_H
 # include <sys/statvfs.h>
 #endif
@@ -227,6 +226,8 @@ _get_path (GPPort *port, const char *folder, const char *file, char *path, unsig
 		char *xpath;
 
 		ret = _get_mountpoint (port, &xpath);
+		if (ret < GP_OK)
+			return ret;
 		snprintf (path, size, "%s/%s/%s", xpath, folder, file);
 	} else {
 		/* old style access */
@@ -439,7 +440,7 @@ set_info_func (CameraFilesystem *fs, const char *folder, const char *file,
 	       CameraFileInfo info, void *data, GPContext *context)
 {
 	int retval;
-	char path_old[1024], path_new[1024], path[1024];
+	char path[1024];
 	Camera *camera = (Camera*)data;
 
 	retval = _get_path (camera->port, folder, file, path, sizeof(path));
@@ -551,7 +552,7 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 		}
 		exif_data_save_data (data, &buf, &buf_len);
 		exif_data_unref (data);
-		gp_file_set_data_and_size (file, buf, buf_len);
+		gp_file_set_data_and_size (file, (char *)buf, buf_len);
 		return (GP_OK);
 #endif /* HAVE_LIBEXIF */
 	default:
@@ -585,7 +586,7 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 			break;
 		}
 		curread += ret;
-		gp_file_append (file, buf, ret);
+		gp_file_append (file, (char *)buf, ret);
 		gp_context_progress_update (context, id, (1.0*curread/BLOCKSIZE));
 		gp_context_idle (context);
 		if (gp_context_cancel (context) == GP_CONTEXT_FEEDBACK_CANCEL) {
