@@ -63,7 +63,6 @@
 #include <sys/types.h>
 
 #include <fcntl.h>
-#include <unistd.h>
 #include <stdlib.h>
 
 #include <gphoto2/gphoto2-port-log.h>
@@ -350,20 +349,34 @@ hp_send_command_and_receive_blob(
 		*msglen = replydatalen;
 		*msg = malloc (replydatalen);
 		ret = gp_port_read (camera->port, (char*)*msg, replydatalen);
-		if (ret < GP_OK)
+		if (ret < GP_OK) {
+			free (*msg);
+			*msg = NULL;
 			return ret;
+		}
 		ret = gp_port_read (camera->port, &eot, 1);
-		if (ret < GP_OK)
+		if (ret < GP_OK) {
+			free (*msg);
+			*msg = NULL;
 			return ret;
-		if (ret != 1)
+		}
+		if (ret != 1) {
+			free (*msg);
+			*msg = NULL;
 			return GP_ERROR_IO;
+		}
 		if (eot != EOT) {
+			free (*msg);
+			*msg = NULL;
 			gp_log (GP_LOG_ERROR, "hp215", "read %02x instead of expected 04", eot);
 			return GP_ERROR_IO;
 		}
 		ackret = hp_send_ack (camera);
-		if (ackret < GP_OK)
+		if (ackret < GP_OK) {
+			free (*msg);
+			*msg = NULL;
 			return ackret;
+		}
 	} else {
 		/* short reply - normal mode, do not copy E0 E0  */
 		*msg = malloc (replydatalen-2);
@@ -371,8 +384,7 @@ hp_send_command_and_receive_blob(
 		memcpy (*msg, msgbuf+5, replydatalen-2);
 	}
 	gp_log (GP_LOG_DEBUG, "hp215", "Read Blob: retcode is %04x", *retcode);
-	gp_log (GP_LOG_DEBUG, "hp215", "Read Blob: argument block is:");
-	gp_log_data ("hp215", (char*)*msg, *msglen);
+	GP_LOG_DATA ((char*)*msg, *msglen, "Read Blob: argument block is:");
 	return GP_OK;
 }
 
