@@ -122,9 +122,21 @@ camera_abilities (CameraAbilitiesList *list)
         if (GP_OK != (ret = gp_abilities_list_append (list, a)))
                 return ret;
 
+        strcpy (a.model, "Pentax:K5II");
+        // same usb vendor like Pentax K5D
+        a.usb_product           = 0x0148;
+        if (GP_OK != (ret = gp_abilities_list_append (list, a)))
+                return ret;
+
         strcpy (a.model, "Pentax:K3");
         // same usb vendor like Pentax K5D
         a.usb_product           = 0x0164;
+        if (GP_OK != (ret = gp_abilities_list_append (list, a)))
+                return ret;
+
+        strcpy (a.model, "Pentax:K3II");
+        // same usb vendor like Pentax K5D
+        a.usb_product           = 0x017a;
         if (GP_OK != (ret = gp_abilities_list_append (list, a)))
                 return ret;
 	return GP_OK;
@@ -176,6 +188,7 @@ camera_summary (Camera *camera, CameraText *summary, GPContext *context)
 		"Using code from pktriggercord by Andras Salamon.\n"
 		"Collected Status Information:\n%s"
 	), statusinfo);
+	free (statusinfo);
 	return GP_OK;
 }
 
