@@ -192,7 +192,7 @@ typedef enum {
 int pslr_get_buffer_status(pslr_handle_t *h, uint32_t *x, uint32_t *y) {
     ipslr_handle_t *p = (ipslr_handle_t *) h;
     DPRINT("[C]\t\tipslr_get_buffer_status()\n");
-    uint8_t buf[800];
+    uint8_t buf[8];
     int n;
 
     CHECK(command(p->fd, 0x02, 0x00, 0));
@@ -206,6 +206,14 @@ int pslr_get_buffer_status(pslr_handle_t *h, uint32_t *x, uint32_t *y) {
     for (i=0; i<n; ++i) {
         DPRINT("[C]\t\tbuf[%d]=%02x\n",i,buf[i]);
     }
+    get_uint32_func get_uint32_func_ptr;
+    if (p->model->is_little_endian) {
+        get_uint32_func_ptr = get_uint32_le;
+    } else {
+        get_uint32_func_ptr = get_uint32_be;
+    }
+    *x = (*get_uint32_func_ptr)(buf);
+    *y = (*get_uint32_func_ptr)(buf+4);
     return PSLR_OK;
 }
 
@@ -1019,6 +1027,19 @@ uint32_t pslr_buffer_read(pslr_handle_t h, uint8_t *buf, uint32_t size) {
     return blksz;
 }
 
+uint32_t pslr_fullmemory_read(pslr_handle_t h, uint8_t *buf, uint32_t offset, uint32_t size) {
+    ipslr_handle_t *p = (ipslr_handle_t *) h;
+    int ret;
+
+    DPRINT("[C]\tpslr_fullmemory_read(%d)\n", size);
+
+    ret = ipslr_download(p, offset, size, buf);
+    if (ret != PSLR_OK) {
+        return 0;
+    }
+    return size;
+}
+
 uint32_t pslr_buffer_get_size(pslr_handle_t h) {
     ipslr_handle_t *p = (ipslr_handle_t *) h;
     int i;
@@ -1499,6 +1520,7 @@ static int _ipslr_write_args(uint8_t cmd_2, ipslr_handle_t *p, int n, ...) {
 
         res = scsi_write(fd, cmd, sizeof (cmd), buf, 4 * n);
         if (res != PSLR_OK) {
+            va_end(ap);
             return res;
         }
     } else {
@@ -1516,6 +1538,7 @@ static int _ipslr_write_args(uint8_t cmd_2, ipslr_handle_t *p, int n, ...) {
             cmd[2] = i * 4;
             res = scsi_write(fd, cmd, sizeof (cmd), buf, 4);
             if (res != PSLR_OK) {
+                va_end(ap);
                 return res;
             }
         }
