@@ -26,8 +26,6 @@
 #include <stdio.h>
 #include <stdarg.h>
 #include <time.h>
-#include <sys/time.h>
-#include <unistd.h>
 
 #include <gphoto2/gphoto2-library.h>
 #include <gphoto2/gphoto2-port-log.h>
@@ -1096,6 +1094,7 @@ chdk_camera_set_config (Camera *camera, CameraWidget *window, GPContext *context
 			continue;
 		if (!gp_widget_changed (widget))
 			continue;
+	        gp_widget_set_changed (widget, FALSE);
 		ret = imgsettings[i].putfunc(params,widget,context);
 		if (ret != GP_OK) {
 			GP_LOG_E("error putting %s menu", imgsettings[i].name);
@@ -1119,18 +1118,14 @@ chdk_camera_capture (Camera *camera, CameraCaptureType type, CameraFilePath *pat
 	int		ret, retint;
 	char		*table, *s;
 	PTPParams	*params = &camera->pl->params;
-	char		*lua;
-	const char	*luascript =	PTP_CHDK_LUA_SERIALIZE_MSGS \
+	const char	*luascript = PTP_CHDK_LUA_SERIALIZE_MSGS_SIMPLEQUOTE \
 				PTP_CHDK_LUA_RLIB_SHOOT	\
 				"return rlib_shoot({info=true});\n";
 
 	ret =  camera_prepare_chdk_capture(camera, context);
 	if (ret != GP_OK) return ret;
 
-	lua = malloc(strlen(luascript)+1);
-	sprintf(lua,luascript); /* This expands the %q inside the string too ... do not optimize away. */
-	ret = chdk_generic_script_run (params, lua, &table, &retint, context);
-	free (lua);
+	ret = chdk_generic_script_run (params, luascript, &table, &retint, context);
 	GP_LOG_D("rlib_shoot returned table %s, retint %d\n", table, retint);
 	s = strstr(table, "exp=");
 	if (s) {
