@@ -32,6 +32,7 @@
 #define PTP_NO_CAPTURE_COMPLETE		DEVICE_FLAG_NO_CAPTURE_COMPLETE
 #define PTP_OLYMPUS_XML			DEVICE_FLAG_OLYMPUS_XML_WRAPPED
 #define PTP_NIKON_1			DEVICE_FLAG_NIKON_1
+#define PTP_DONT_CLOSE_SESSION		DEVICE_FLAG_DONT_CLOSE_SESSION
 
 #define DELETE_SENDS_EVENT(x) \
   ((x)->device_flags & (DEVICE_FLAG_DELETE_SENDS_EVENT))
@@ -39,6 +40,8 @@
   ((x)->device_flags & (DEVICE_FLAG_NIKON_BROKEN_CAPTURE))
 #define NIKON_1(x) \
   ((x)->device_flags & (DEVICE_FLAG_NIKON_1))
+#define DONT_CLOSE_SESSION(x) \
+  ((x)->device_flags & (DEVICE_FLAG_DONT_CLOSE_SESSION))
 #define NO_CAPTURE_COMPLETE(x) \
   ((x)->device_flags & (DEVICE_FLAG_NO_CAPTURE_COMPLETE))
 #define MTP_ZEN_BROKEN_HEADER(x) \
