@@ -23,7 +23,6 @@
 #include <time.h>
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
 
 #include <gphoto2/gphoto2-library.h>
 #include <gphoto2/gphoto2-result.h>
@@ -485,8 +484,8 @@ delete_file_func (CameraFilesystem *fs, const char *folder,
 		ret = GP_ERROR;
 	}
 out:
-	if (cmd) free(cmd);
-	if (reply) free(reply);
+	free(cmd);
+	free(reply);
 	return (GP_OK);
 }
 
@@ -513,8 +512,8 @@ rmdir_func (CameraFilesystem *fs, const char *folder,
 		ret = GP_ERROR;
 	}
 out:
-	if (cmd) free(cmd);
-	if (reply) free(reply);
+	free(cmd);
+	free(reply);
 	return (GP_OK);
 }
 
@@ -541,8 +540,8 @@ mkdir_func (CameraFilesystem *fs, const char *folder,
 		ret = GP_ERROR;
 	}
 out:
-	if (cmd) free(cmd);
-	if (reply) free(reply);
+	free(cmd);
+	free(reply);
 	return (GP_OK);
 }
 
@@ -606,7 +605,7 @@ camera_summary (Camera *camera, CameraText *summary, GPContext *context)
 			sprintf(t+strlen(t), _("Internal memory: %d MB total, %d MB free.\n"), space/1024/1024, sfree/1024/1024);
 		}
 	}
-	if (buf) free (buf);
+	free (buf);
 	return (GP_OK);
 }
 
@@ -688,7 +687,7 @@ get_info_func (CameraFilesystem *fs, const char *folder, const char *filename,
 		}
 	}
 out:
-	if (reply) free(reply);
+	free(reply);
 	free(cmd);
 
 	return (GP_OK);
