@@ -1,6 +1,6 @@
 /* library.h
  *
- * Copyright  2001 Lutz Mller <lutz@users.sf.net>
+ * Copyright 2001 Lutz Mueller <lutz@users.sf.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 
 #ifndef __LIBRARY_H__
@@ -30,7 +30,7 @@
 	int res = (result);					\
 								\
 	if (res < 0) {						\
-		GP_DEBUG ("Operation failed (%i)!", res);	\
+		GP_DEBUG ("Operation failed in %s (%i)!", __FUNCTION__, res);	\
 		camera_stop (camera, context);			\
 		return (res);					\
 	}							\
@@ -41,7 +41,7 @@
 	int res = (result);					\
 								\
 	if (res < 0) {						\
-		GP_DEBUG ("Operation failed (%i)!", res);	\
+		GP_DEBUG ("Operation failed in %s (%i)!", __FUNCTION__, res);	\
 		camera_stop (camera, context);			\
 		free (camera->pl);				\
 		camera->pl = NULL;				\
@@ -54,7 +54,7 @@
 	int res = (result);					\
 								\
 	if (res < 0) {						\
-		GP_DEBUG ("Operation failed (%i)!", res);	\
+		GP_DEBUG ("Operation failed in %s (%i)!", __FUNCTION__, res);	\
 		free (camera->pl);				\
 		camera->pl = NULL;				\
 		return (res);					\
