@@ -14,13 +14,17 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
+
+#define _BSD_SOURCE
+
 #include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <locale.h>
 
 #include <gphoto2/gphoto2-port-log.h>
 #include <gphoto2/gphoto2-library.h>
@@ -33,6 +37,7 @@
 
 #define GP_MODULE "Smal Ultrapocket"
 
+#include <locale.h>
 #ifdef ENABLE_NLS
 #  include <libintl.h>
 #  undef _
@@ -62,9 +67,9 @@ static int
 ultrapocket_command(GPPort *port, int iswrite, unsigned char *data, int datasize) {
     int ret;
     if (iswrite)
-	ret = gp_port_write(port, data, datasize);
+	ret = gp_port_write(port, (char *)data, datasize);
     else
-        ret = gp_port_read(port, data, datasize);
+        ret = gp_port_read(port, (char *)data, datasize);
 
     return ret;
 }
@@ -204,7 +209,6 @@ int
 ultrapocket_getrawpicture(Camera *camera, GPContext *context, 
    unsigned char **pdata, int *size, const char *filename)
 {
-    char           *savelocale;
     char           ppmheader[200];
     unsigned char *rawdata,*outdata;
     int            width, height, result;
@@ -228,28 +232,28 @@ ultrapocket_getrawpicture(Camera *camera, GPContext *context,
 	imgstart = 0x29;
 	break;
      default:
-	break;
+        return GP_ERROR;
     }
 
    tile = BAYER_TILE_BGGR;
 
-   savelocale = setlocale(LC_ALL, "C");
    snprintf (ppmheader, sizeof(ppmheader), "P6\n"
 	    "# CREATOR: gphoto2, ultrapocket library, raw,"
 	    " assuming Bayer tile %s\n"
 	    "%d %d\n"
 	    "255\n", BayerTileNames[tile], width, height);
-   setlocale(LC_ALL, savelocale);
 
    /* Allocate memory for Interpolated ppm image */
    pmmhdr_len = strlen(ppmheader);
    outsize = ((long)width + 4) * height * 3 + pmmhdr_len;
    outdata = malloc(outsize);
-   if (!outdata)
+   if (!outdata) {
+     free(rawdata);
      return (GP_ERROR_NO_MEMORY);
+   }
 
    /* Set header */
-   strcpy(outdata, ppmheader);
+   strcpy((char *)outdata, ppmheader);
 
    /* Expand the Bayer tiles */
    result = gp_bayer_expand((rawdata+imgstart), width + 4, height,
@@ -281,7 +285,7 @@ ultrapocket_getrawpicture(Camera *camera, GPContext *context,
 int
 ultrapocket_getpicture(Camera *camera, GPContext *context, unsigned char **pdata, int *size, const char *filename)
 {
-    char           *savelocale;
+    char	   *savelocale;
     char           ppmheader[200];
     unsigned char *rawdata,*outdata;
     int            width, height, result;
@@ -313,7 +317,7 @@ ultrapocket_getpicture(Camera *camera, GPContext *context, unsigned char **pdata
 
    tile = BAYER_TILE_BGGR;
 
-   savelocale = setlocale(LC_ALL, "C");
+   savelocale = setlocale (LC_ALL, "C");
    snprintf (ppmheader, sizeof(ppmheader), "P6\n"
 	    "# CREATOR: gphoto2, ultrapocket library,"
 	    " assuming Bayer tile %s, interpolated"
@@ -326,7 +330,7 @@ ultrapocket_getpicture(Camera *camera, GPContext *context, unsigned char **pdata
 	    GAMMA_NUMBER,
 #endif
 	    width, height);
-   setlocale(LC_ALL, savelocale);
+   setlocale (LC_ALL, savelocale);
 
    /* Allocate memory for Interpolated ppm image */
    pmmhdr_len = strlen(ppmheader);
@@ -338,7 +342,7 @@ ultrapocket_getpicture(Camera *camera, GPContext *context, unsigned char **pdata
    }
 
    /* Set header */
-   strcpy(outdata, ppmheader);
+   strcpy((char *)outdata, ppmheader);
 
    /* Decode and interpolate the Bayer tiles */
    result = gp_bayer_decode((rawdata+imgstart), width+4, height,
@@ -379,8 +383,8 @@ ultrapocket_reset(Camera *camera)
    GPPortInfo oldpi;
    GPPort *port = camera->port;
    CameraAbilities cab;
-   gp_camera_get_abilities(camera, &cab);
    unsigned char cmdbuf[0x10];
+   gp_camera_get_abilities(camera, &cab);
    GP_DEBUG ("First connect since camera was used - need to reset cam");
 
    /*
@@ -413,7 +417,7 @@ ultrapocket_skip(GPPort *port, int npackets)
 
    gp_port_get_timeout(port, &old_timeout);
    gp_port_set_timeout(port, 100);
-   for (; (npackets > 0) && gp_port_read(port, retbuf, 0x1000); npackets--);
+   for (; (npackets > 0) && gp_port_read(port, (char *)retbuf, 0x1000); npackets--);
    gp_port_set_timeout(port, old_timeout);
    return GP_OK;
 }
