@@ -1,6 +1,21 @@
 /*
  * agfa_cl18.c
  *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful, 
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of 
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details. 
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
+ *
  *  Command set specific to agfa-ephoto-CL18
  *
  * Copyright 2001-2002 Vince Weaver <vince@deater.net>
@@ -15,7 +30,6 @@
 #ifdef OS2
 #include <db.h>
 #endif
-#include <unistd.h>
 
 #include <gphoto2/gphoto2.h>
 #include "gphoto2-endian.h"
