@@ -13,17 +13,19 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, write to the 
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
+#define _BSD_SOURCE
 #include "config.h"
 
 #include <string.h>
 #include <stdlib.h>
-#ifdef HAVE_ICONV
+#if defined(HAVE_ICONV) && defined(HAVE_LANGINFO_H)
 # include <langinfo.h>
 #endif
-#ifdef HAVE_GD
+#ifdef HAVE_LIBGD
 # include <gd.h>
 #endif
 
@@ -128,7 +130,7 @@ static int get_file_idx(CameraPrivateLibrary *pl, const char *folder,
 	return i;
 }
 
-#ifdef HAVE_GD
+#ifdef HAVE_LIBGD
 static void
 rotate90 (gdImagePtr src, gdImagePtr dest)
 {
@@ -179,7 +181,7 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 {
 	Camera *camera = data;
 	int idx, size;
-#ifdef HAVE_GD
+#ifdef HAVE_LIBGD
 	int ret;
 	gdImagePtr im, rotated;
 	void *gdpng;
@@ -202,7 +204,7 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 		return GP_OK;
 	}
 
-#ifdef HAVE_GD
+#ifdef HAVE_LIBGD
 	if (type != GP_FILE_TYPE_NORMAL)
 		return GP_ERROR_NOT_SUPPORTED;
 
@@ -251,14 +253,16 @@ static int
 put_file_func (CameraFilesystem *fs, const char *folder, const char *name, 
 	CameraFileType type, CameraFile *file, void *data, GPContext *context)
 {
-#ifdef HAVE_GD
+#ifdef HAVE_LIBGD
 	Camera *camera = data;
 	char *c, *in_name, *out_name, *filedata = NULL;
 	int ret, in_width, in_height, in_x, in_y;
 	size_t inc, outc;
 	double aspect_in, aspect_out;
-#ifdef HAVE_ICONV
+#if defined(HAVE_ICONV) && defined(HAVE_LANGINFO_H)
 	char *in, *out;
+#else
+	int i;
 #endif
 	unsigned long filesize = 0;
 	gdImagePtr rotated, im_out, im_in = NULL;
@@ -277,7 +281,7 @@ put_file_func (CameraFilesystem *fs, const char *folder, const char *name,
 	}
 
 	/* Convert name to ASCII */
-#ifdef HAVE_ICONV
+#if defined(HAVE_ICONV) && defined(HAVE_LANGINFO_H)
 	in = in_name;
 	out = out_name;
 	if (iconv (camera->pl->cd, &in, &inc, &out, &outc) == -1) {
@@ -590,7 +594,7 @@ camera_exit (Camera *camera, GPContext *context)
 		gp_setting_set ("st2205", "syncdatetime", buf);
 		gp_setting_set ("st2205", "orientation", orientation_to_string
 						(camera->pl->orientation));
-#ifdef HAVE_ICONV
+#if defined(HAVE_ICONV) && defined(HAVE_LANGINFO_H)
 		if (camera->pl->cd != (iconv_t) -1)
 			iconv_close (camera->pl->cd);
 #endif
@@ -605,7 +609,7 @@ int
 camera_init (Camera *camera, GPContext *context) 
 {
 	int i, j, ret;
-#ifdef HAVE_ICONV
+#if defined(HAVE_ICONV) && defined(HAVE_LANGINFO_H)
 	char *curloc;
 #endif
 	char buf[256];
@@ -639,7 +643,7 @@ camera_init (Camera *camera, GPContext *context)
 			camera->pl->orientation = ret;
 	}
 
-#ifdef HAVE_ICONV
+#if defined(HAVE_ICONV) && defined(HAVE_LANGINFO_H)
 	curloc = nl_langinfo (CODESET);
 	if (!curloc)
 		curloc="UTF-8";
@@ -695,12 +699,20 @@ camera_init (Camera *camera, GPContext *context)
 
 	/* Sync time if requested */
 	if (camera->pl->syncdatetime) {
+#ifdef HAVE_LOCALTIME_R
 		struct tm tm;
+#endif
+		struct tm *xtm;
 		time_t t;
 
 		t = time (NULL);
-		if (localtime_r (&t , &tm)) {
-			ret = st2205_set_time_and_date (camera, &tm);
+
+#ifdef HAVE_LOCALTIME_R
+		if ((xtm = localtime_r (&t , &tm))) {
+#else
+		if ((xtm = localtime (&t))) {
+#endif
+			ret = st2205_set_time_and_date (camera, xtm);
 			if (ret != GP_OK) {
 				camera_exit (camera, context);
 				return ret;
