@@ -53,7 +53,6 @@
 #include <utime.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <unistd.h>
 #include <fcntl.h>
 
 #if defined(HAVE_ICONV) && defined(HAVE_LANGINFO_H)
@@ -343,7 +342,6 @@ do_cmd_ready(Camera *camera, GPContext *context)
 
 	case FAIL:
 		gp_log (GP_LOG_ERROR, "topfield", "ERROR: Device reports %s\n", decode_error(&reply));
-		get_u32(&reply.data);
 		break;
 
 	default:
@@ -589,6 +587,7 @@ camera_config_set (Camera *camera, CameraWidget *window, GPContext *context)
 		const char* val;
 		int ival;
 
+	        gp_widget_set_changed (turbo, FALSE);
 		ret = gp_widget_get_value (turbo, &val);
 		if (ret == GP_OK) {
 			ival = !strcmp (val, _("On"));
