@@ -11,11 +11,11 @@ var gphoto2_port_log_8c =
     [ "HEXDUMP_MIDDLE", "gphoto2-port-log_8c.html#ae21578f6dac5be34d83475a83e271d73", null ],
     [ "HEXDUMP_OFFSET_WIDTH", "gphoto2-port-log_8c.html#a425183fc022968cf26219b38421b42ee", null ],
     [ "N_", "gphoto2-port-log_8c.html#a75278405e7f034d2b1af80bfd94675fe", null ],
-    [ "xargs", "gphoto2-port-log_8c.html#a3b5dcab5cde5c5c3e39255d892765fc1", null ],
     [ "gp_log", "gphoto2-port-log_8c.html#a77325969d9eb7e1b9c2285233c7b3862", null ],
     [ "gp_log_add_func", "gphoto2-port-log_8c.html#aad08200a2e1b98c54ba32e8c80bfac6c", null ],
-    [ "gp_log_data", "gphoto2-port-log_8c.html#a1f87fb4d74a1713ca959ebee544ba860", null ],
+    [ "gp_log_data", "gphoto2-port-log_8c.html#acb3fc0f7a49dd49fa8bdbe4cdaacdd0a", null ],
     [ "gp_log_remove_func", "gphoto2-port-log_8c.html#a0b14529482e5bc725bcc003583337ea7", null ],
     [ "gp_log_with_source_location", "gphoto2-port-log_8c.html#ac724677ed0dfe9431fac69c30e2cb39b", null ],
-    [ "gp_logv", "gphoto2-port-log_8c.html#a07601ec204167a55885e02b80edd3fcf", null ]
+    [ "gp_logv", "gphoto2-port-log_8c.html#a07601ec204167a55885e02b80edd3fcf", null ],
+    [ "gpi_vsnprintf", "gphoto2-port-log_8c.html#a5e9bad704f3b065a2d5b653c7516a1ee", null ]
 ];
\ No newline at end of file
