@@ -33,7 +33,6 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <errno.h>
-#include <unistd.h>
 #include <string.h>
 #include <sys/stat.h>
 #include <utime.h>
@@ -95,6 +94,8 @@ gp_file_new (CameraFile **file)
 
 
 /*! Create new #CameraFile object from a UNIX filedescriptor.
+ *
+ * This function takes ownership of the filedescriptor and will close it when closing the CameraFile.
  *
  * \param file a pointer to a #CameraFile
  * \param fd a UNIX filedescriptor
@@ -893,7 +894,7 @@ gp_file_get_name (CameraFile *file, const char **name)
 int
 gp_file_get_name_by_type (CameraFile *file, const char *basename, CameraFileType type, char **newname)
 {
-	char *prefix = NULL, *s, *new;
+	char *prefix = NULL, *s, *new, *slash = NULL;
 	const char *suffix = NULL;
 	int i;
 
@@ -913,6 +914,9 @@ gp_file_get_name_by_type (CameraFile *file, const char *basename, CameraFileType
 		}
 	}
 	s = strrchr(basename,'.');
+	slash = strrchr(basename,'/');
+	if (slash > s)	/* --filename foo.bar/foo */
+		s = NULL;
 	switch (type) {
 	case GP_FILE_TYPE_RAW:		prefix = "raw_";break;
 	case GP_FILE_TYPE_EXIF:		prefix = "exif_";break;
@@ -923,19 +927,34 @@ gp_file_get_name_by_type (CameraFile *file, const char *basename, CameraFileType
 	}
 	if (s) {
 		int xlen;
+
 		if (!suffix)
 			suffix = s+1;
-		C_MEM (new = malloc (strlen(prefix) + (s-basename+1) + strlen (suffix) + 1));
-		strcpy (new, prefix);
-		xlen = strlen (new);
-		memcpy (new+xlen, basename, s-basename+1);
+
+		C_MEM (new = calloc (strlen(prefix) + (s-basename+1) + strlen (suffix) + 1, 1));
+
+		xlen = strlen (prefix);
+		if (slash) {
+			memcpy (new, basename, slash-basename+1);
+			strcat (new, prefix);
+			memcpy (new + strlen (new), slash+1, s-slash+1);
+		} else {
+			strcpy (new, prefix);
+			memcpy (new + strlen (new), basename, s-basename+1);
+		}
 		new[xlen+(s-basename)+1]='\0';
 		strcat (new, suffix);
 	} else { /* no dot in basename? */
 		if (!suffix) suffix = "";
-		C_MEM (new = malloc (strlen(prefix) + strlen(basename) + 1 + strlen (suffix) + 1));
-		strcpy (new, prefix);
-		strcat (new, basename);
+		C_MEM (new = calloc (strlen(prefix) + strlen(basename) + 1 + strlen (suffix) + 1, 1));
+		if (slash) {
+			memcpy (new, basename, slash-basename+1); /* with / */
+			strcat (new, prefix);
+			strcat (new, slash+1);
+		} else {
+			strcpy (new, prefix);
+			strcat (new, basename);
+		}
 		if (strlen(suffix)) {
 			strcat (new, ".");
 			strcat (new, suffix);
@@ -1074,6 +1093,7 @@ gp_file_adjust_name_for_mime_type (CameraFile *file)
 		GP_MIME_AVI,  "avi",
 		GP_MIME_CRW,  "crw",
 		GP_MIME_CR2,  "cr2",
+		GP_MIME_NEF,  "nef",
 		GP_MIME_TXT,  "txt",
 		NULL};
 
