@@ -21,7 +21,7 @@
  * Boston, MA  02110-1301  USA
  */
 
-#define _BSD_SOURCE
+#define _DEFAULT_SOURCE
 
 #include "config.h"
 #include <gphoto2/gphoto2-setting.h>
@@ -29,12 +29,15 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
 
 #include <gphoto2/gphoto2-result.h>
 #include <gphoto2/gphoto2-port-log.h>
 #include <gphoto2/gphoto2-port-portability.h>
 
+#ifdef WIN32
+#include <Shlobj.h>
+#endif
+
 /**
  * Internal struct to store settings.
  */
@@ -59,7 +62,7 @@ static int load_settings (void);
  * \brief Retrieve a specific gphoto setting.
  * \param id the frontend id of the caller
  * \param key the key the frontend queries
- * \param value retrieved value
+ * \param value changed value
  * \return GPhoto error code
  *
  * This function retrieves the setting key for a specific frontend
@@ -91,7 +94,7 @@ gp_setting_get (char *id, char *key, char *value)
  *
  * \param id the frontend id of the caller
  * \param key the key the frontend queries
- * \param value retrieved value
+ * \param value new value
  * \return GPhoto error code
  *
  * This function sets the setting key for a specific frontend
@@ -133,7 +136,7 @@ verify_settings (char *settings_file)
 	unsigned int x, equals;
 
 	if ((f=fopen(settings_file, "r"))==NULL) {
-		GP_LOG_E ("Can't open settings file for reading.");
+		GP_LOG_D ("Can't open settings file '%s' for reading.", settings_file);
 		return(0);
 	}
 
@@ -169,19 +172,19 @@ load_settings (void)
 	char buf[1024], *id, *key, *value;
 
 	/* Make sure the directories are created */
-	GP_LOG_D ("Creating $HOME/.gphoto");
 #ifdef WIN32
-	GetWindowsDirectory (buf, sizeof(buf));
-	strcat (buf, "\\gphoto");
+	SHGetFolderPath(NULL, CSIDL_PROFILE, NULL, 0, buf);
+	strcat (buf, "\\.gphoto");
 #else
 	snprintf (buf, sizeof(buf), "%s/.gphoto", getenv ("HOME"));
 #endif
+	GP_LOG_D ("Creating gphoto config directory ('%s')", buf);
 	(void)gp_system_mkdir (buf);
 
 	glob_setting_count = 0;
 #ifdef WIN32
-	GetWindowsDirectory(buf, sizeof(buf));
-	strcat(buf, "\\gphoto\\settings");
+	SHGetFolderPath(NULL, CSIDL_PROFILE, NULL, 0, buf);
+	strcat(buf, "\\.gphoto\\settings");
 #else
 	snprintf(buf, sizeof(buf), "%s/.gphoto/settings", getenv("HOME"));
 #endif
@@ -192,7 +195,7 @@ load_settings (void)
 	GP_LOG_D ("Loading settings from file '%s'.", buf);
 
 	if ((f=fopen(buf, "r"))==NULL) {
-		GP_LOG_D ("Can't open settings file for reading.");
+		GP_LOG_D ("Can't open settings file '%s' for reading.", buf);
 		return(GP_ERROR);
 	}
 
@@ -226,7 +229,13 @@ save_settings (void)
 	char buf[1024];
 	int x=0;
 
+#ifdef WIN32
+	SHGetFolderPath(NULL, CSIDL_PROFILE, NULL, 0, buf);
+	strcat(buf, "\\.gphoto\\settings");
+#else
 	snprintf (buf, sizeof(buf), "%s/.gphoto/settings", getenv ("HOME"));
+#endif
+
 
 	GP_LOG_D ("Saving %i setting(s) to file \"%s\"", glob_setting_count, buf);
 
