@@ -25,15 +25,9 @@
 #include <gphoto2/gphoto2-port-library.h>
 
 #include <stdlib.h>
-#include <unistd.h>
 #include <stdio.h>
 #include <fcntl.h>
 #include <errno.h>
-#include <sys/time.h>
-#ifdef HAVE_SYS_PARAM_H
-#include <sys/param.h>
-#endif
-#include <dirent.h>
 #include <string.h>
 #ifdef HAVE_MNTENT_H
 # include <mntent.h>
@@ -121,23 +115,29 @@ gp_port_library_list (GPPortInfoList *list)
                             (NULL != strstr(mntent->mnt_fsname,"devtmpfs"))||
                             (NULL != strstr(mntent->mnt_fsname,"devpts"))||
                             (NULL != strstr(mntent->mnt_fsname,"sysfs"))||
-			    (NULL != strstr(mntent->mnt_fsname,"gphotofs")||
+			    (NULL != strstr(mntent->mnt_fsname,"gphotofs"))||
 			/* fstype based */
 			    (NULL != strstr(mntent->mnt_type,"autofs"))	||
 			    (NULL != strstr(mntent->mnt_type,"nfs"))	||
 			    (NULL != strstr(mntent->mnt_type,"smbfs"))||
 			    (NULL != strstr(mntent->mnt_type,"proc"))||
 			    (NULL != strstr(mntent->mnt_type,"sysfs"))||
-			    (NULL != strstr(mntent->mnt_type,"fuse"))||
 			    (NULL != strstr(mntent->mnt_type,"cifs"))||
 			    (NULL != strstr(mntent->mnt_type,"afs")) ||
 			/* mount options */
 				/* x-systemd.automount or similar */
 			    (NULL != strstr(mntent->mnt_opts,"automount"))
-)
 			) {
 				continue;
 			}
+
+			/* Whitelist some fuse based filesystems, e.g. to help exfat mounts */
+			/* In general, if we are backed by a device, it is probably good(tm) */
+			if (NULL != strstr(mntent->mnt_type,"fuse")) {
+				if (!strstr(mntent->mnt_fsname,"/dev/"))
+					continue;
+			}
+
 			snprintf (path, sizeof(path), "%s/DCIM", mntent->mnt_dir);
 			if (-1 == stat(path, &stbuf)) {
 				snprintf (path, sizeof(path), "%s/dcim", mntent->mnt_dir);
@@ -192,7 +192,6 @@ gp_port_library_list (GPPortInfoList *list)
 			    (NULL != strstr(mntent->mnt_type,"smbfs"))||
 			    (NULL != strstr(mntent->mnt_type,"proc"))||
 			    (NULL != strstr(mntent->mnt_type,"sysfs"))||
-			    (NULL != strstr(mntent->mnt_type,"fuse"))||
 			    (NULL != strstr(mntent->mnt_type,"cifs"))||
 			    (NULL != strstr(mntent->mnt_type,"afs")) ||
 			/* options */
@@ -200,6 +199,12 @@ gp_port_library_list (GPPortInfoList *list)
 			) {
 				continue;
 			}
+			/* Whitelist some fuse based filesystems, e.g. to help exfat mounts */
+			/* In general, if we are backed by a device, it is probably good(tm) */
+			if (NULL != strstr(mntent->mnt_type,"fuse")) {
+				if (!strstr(mntent->mnt_fsname,"/dev/"))
+					continue;
+			}
 
 			snprintf (path, sizeof(path), "%s/DCIM", mntent->mnt_dir);
 			if (-1 == stat(path, &stbuf)) {
@@ -290,13 +295,12 @@ gp_port_library_list (GPPortInfoList *list)
 	}
 #  endif
 # endif
-
 	/* generic disk:/xxx/ matcher */
 	gp_port_info_new (&info);
 	gp_port_info_set_type (info, GP_PORT_DISK);
 	gp_port_info_set_name (info, "");
 	gp_port_info_set_path (info, "^disk:");
-	CHECK (gp_port_info_list_append (list, info));
+	gp_port_info_list_append (list, info); /* do not check return */
 	return GP_OK;
 }
 
