@@ -1,6 +1,6 @@
-/* gphoto2-port-version.c
+/** \file
  *
- * Copyright  2002 Hans Ulrich Niedermann <gp@n-dimensional.de
+ * Copyright 2002 Hans Ulrich Niedermann <gp@n-dimensional.de
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 
 #include "config.h"
@@ -29,7 +29,8 @@ const char **gp_port_library_version(GPVersionVerbosity verbose)
 	   ones, but the current method is easier for now :-) */
 	static const char *shrt[] =
 		{
-			VERSION,
+			PACKAGE_VERSION,
+			"iolibs: " IOLIB_LIST,
 #ifdef HAVE_CC
 			HAVE_CC,
 #else
@@ -40,7 +41,7 @@ const char **gp_port_library_version(GPVersionVerbosity verbose)
 #else
 			"no ltdl",
 #endif
-#ifdef HAVE_LIBUSB
+#if defined(HAVE_LIBUSB) || defined(HAVE_LIBUSB1) || defined(HAVE_LIBUSB_WIN32)
 			"USB",
 #else
 			"no USB",
@@ -50,8 +51,6 @@ const char **gp_port_library_version(GPVersionVerbosity verbose)
 
 #ifdef HAVE_RESMGR
 			"resmgr locking",
-#elif HAVE_BAUDBOY
-			"baudboy locking",
 #elif HAVE_TTYLOCK
 			"ttylock locking",
 #elif HAVE_LOCKDEV
@@ -67,21 +66,24 @@ const char **gp_port_library_version(GPVersionVerbosity verbose)
 		};
 	static const char *verb[] =
 		{
-			VERSION,
+			PACKAGE_VERSION,
+			"iolibs: " IOLIB_LIST,
 #ifdef HAVE_CC
 			HAVE_CC " (C compiler used)",
 #else
 			"unknown (C compiler used)",
 #endif
 #ifdef HAVE_LTDL
-			"ltdl (for portable loading of camlibs)",
+			"ltdl (for portable loading of iolibs)",
 #else
-			"no ltdl (for portable loading of camlibs)",
+			"no ltdl (for portable loading of iolibs)",
 #endif
 #ifdef HAVE_LIBUSB_WIN32
 			"USB (libusb-win32, for USB cameras)",
+#elif defined(HAVE_LIBUSB1)
+			"USB (libusb1, for USB cameras)",
 #elif defined(HAVE_LIBUSB)
-			"USB (libusb, for USB cameras)",
+			"USB (libusb0, for USB cameras)",
 #else
 			"no USB (for USB cameras)",
 #endif
@@ -95,11 +97,6 @@ const char **gp_port_library_version(GPVersionVerbosity verbose)
 #else
 			"no resmgr (serial port access and locking)",
 #endif
-#ifdef HAVE_BAUDBOY
-			"baudboy (serial port locking)",
-#else
-			"no baudboy (serial port locking)",
-#endif
 #ifdef HAVE_TTYLOCK
 			"ttylock (serial port locking)",
 #else
