@@ -27,12 +27,11 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "__stdint_8h_source.html",
-"gphoto2-camera_8c.html",
-"gphoto2-file_8h.html#ab9f339bdf374343272c62d2352753d69a5f9e4fc5c19d2f49b1539d61ebc7d824",
-"gphoto2-port-info-list_8h.html#a70f65ef80a59174adfa52c3e199752d4",
-"gphoto2-setting_8c.html",
-"struct__CameraFileInfoPreview.html#a12d6115703a502a24cd5b193b75d666a",
-"template_8c.html#a9127c82b044f56fac4cbceb92b9e0217"
+"gphoto2-camera_8h.html#a95f595a6d9bfe68d99419a0087363f89",
+"gphoto2-filesys_8h.html#a7bbfa59b2587d36fa5be529c788f9585",
+"gphoto2-port-version_8h.html#a293e53d10075f8c09b39325d8e54be43",
+"jpeg_8c.html#a4aee2400e444196497aaf51b5bda674b",
+"struct__CameraWidget.html"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
