@@ -45,114 +45,11 @@ var NAVTREEINDEX0 =
 "dir_df723b3f25cfe80b0e773fc78a5873a4.html":[2,0,2],
 "dir_ff2570e7e5c377838c8e56ea8c3b24f7.html":[2,0,3,0],
 "exif_8c.html":[2,0,2,4],
-"exif_8c.html#a56788ab4a12570038f5758fba697f871":[2,0,2,4,0],
-"exif_8c.html#a644a0250af4ab37d8609d6bf6a1c7e00":[2,0,2,4,1],
+"exif_8c.html#addf34b3ba9fb5b467384cf758966170b":[2,0,2,4,1],
+"exif_8c.html#aefbbfb47ade88403c2f07fefcb9abb25":[2,0,2,4,0],
 "exif_8h.html":[2,0,2,5],
-"exif_8h.html#a0094a4189503f6508a1f8859cfbddf62":[2,0,2,5,76],
-"exif_8h.html#a009d39cfc7ff849027a0e1a76bd72001":[2,0,2,5,31],
-"exif_8h.html#a091f51a628c5b56ec1da763e4f99267a":[2,0,2,5,7],
-"exif_8h.html#a0afa6e558e8bc4733c8d77346eacbf6a":[2,0,2,5,10],
-"exif_8h.html#a0fc6ace2828970aee40f18615b4bc791":[2,0,2,5,4],
-"exif_8h.html#a112f41e58e7c58a20b6fe90dd60dec94":[2,0,2,5,14],
-"exif_8h.html#a11e6a3f8f9f4904b14690fee7ebe2fab":[2,0,2,5,51],
-"exif_8h.html#a126a303802c906bcddcba0c0b6b65d39":[2,0,2,5,33],
-"exif_8h.html#a12f2d13246e91f2bfcb9973f8d0d83ea":[2,0,2,5,90],
-"exif_8h.html#a14aeba2e91a9538e0e15ee1d9c16ed37":[2,0,2,5,26],
-"exif_8h.html#a164b3a03a4fddcc5e93a4d1a20de17f6":[2,0,2,5,72],
-"exif_8h.html#a17e5ecfbb4f13723d20e4f09eed14d51":[2,0,2,5,2],
-"exif_8h.html#a1a0e04d62f1f84b0145d86b539975b2a":[2,0,2,5,9],
-"exif_8h.html#a24dcb11a7cb7f3fb7eec347e8b2811c1":[2,0,2,5,40],
-"exif_8h.html#a24f15e9c24afd625a4d052f16d83791e":[2,0,2,5,22],
-"exif_8h.html#a271a5ba87bdb9e9953489459f7b47e61":[2,0,2,5,38],
-"exif_8h.html#a3065f4dc8c0dc6f6c86eeba2821b1fc5":[2,0,2,5,43],
-"exif_8h.html#a32d950c77c21558d699ea9900a8e7790":[2,0,2,5,67],
-"exif_8h.html#a36f57376b1627dc23c8e7a9f1f362b42":[2,0,2,5,5],
-"exif_8h.html#a388772d126f7b86d603b9c3843a6dc5a":[2,0,2,5,61],
-"exif_8h.html#a3a2a8f7979959d9811992461a55868c1":[2,0,2,5,21],
-"exif_8h.html#a4168b15e174a3e8dcb376ed4d7fabcbc":[2,0,2,5,45],
-"exif_8h.html#a47a74932e4e37244895bd64b2b0a2afb":[2,0,2,5,57],
-"exif_8h.html#a488d8270f0b32aba22d967ae55dee9a6":[2,0,2,5,23],
-"exif_8h.html#a4cbde3f25488d8132846cf1c706a35ae":[2,0,2,5,58],
-"exif_8h.html#a5188c2edc89aed614e77bb1b894a4fab":[2,0,2,5,8],
-"exif_8h.html#a5282df8295787c3dff7bcbe383b5b559":[2,0,2,5,85],
-"exif_8h.html#a56788ab4a12570038f5758fba697f871":[2,0,2,5,92],
-"exif_8h.html#a5920ec6e6fb1ce6f2a4fb139849ef6f0":[2,0,2,5,66],
-"exif_8h.html#a5a39e277521d6f30f2397ce1888cc650":[2,0,2,5,24],
-"exif_8h.html#a5aed67ff7143d020f3d3c1a4ec30a8b5":[2,0,2,5,27],
-"exif_8h.html#a5c19da757bb98d3b88adad7dadc2f1f7":[2,0,2,5,28],
-"exif_8h.html#a5c8e47216801ffdde5a83fce175bca2e":[2,0,2,5,39],
-"exif_8h.html#a5f8da5d293aa35a5ebf5d48bb72d08b6":[2,0,2,5,47],
-"exif_8h.html#a5ffe5003b58ccae71196edc1b5da2a6c":[2,0,2,5,46],
-"exif_8h.html#a6039b4c6c42652636d79bd589ce4804e":[2,0,2,5,42],
-"exif_8h.html#a63b0ec0a9b76c9b53b53cd6c2bfd7968":[2,0,2,5,54],
-"exif_8h.html#a644a0250af4ab37d8609d6bf6a1c7e00":[2,0,2,5,93],
-"exif_8h.html#a6733e8c3d08ce8424da18ea789f9988f":[2,0,2,5,89],
-"exif_8h.html#a6a980170be962cbd8a89e4ac7df89322":[2,0,2,5,65],
-"exif_8h.html#a6e0652f00ad97c54414dcf3910aa9829":[2,0,2,5,37],
-"exif_8h.html#a70998aa4502179b1b220fd8e8cf796b1":[2,0,2,5,82],
-"exif_8h.html#a71d2cc0d8c967b478d984581b48c3176":[2,0,2,5,56],
-"exif_8h.html#a7446eb598d5ccd1ed35ceb8b16ad2565":[2,0,2,5,19],
-"exif_8h.html#a7c6fa90e3cc6c1cd535df09094df73b6":[2,0,2,5,16],
-"exif_8h.html#a7f371e5367f79d135f4dbce2c2e9c945":[2,0,2,5,81],
-"exif_8h.html#a8cd48dac508880b532003c669e858065":[2,0,2,5,84],
-"exif_8h.html#a8d9fcff32740dcc29e1a2a4e7e267741":[2,0,2,5,59],
-"exif_8h.html#a8da958fa9c9a9cc418e49a66498f1487":[2,0,2,5,86],
-"exif_8h.html#a8dc34151a98a4a6281a82bfd498a328c":[2,0,2,5,25],
-"exif_8h.html#a8dda91d1ca8fb28d821297c9e3e11204":[2,0,2,5,18],
-"exif_8h.html#a8e1fe1ff27d4b50d56bd28ded0a7afef":[2,0,2,5,69],
-"exif_8h.html#a9504e12e7b239a710d0db64a03befdf6":[2,0,2,5,79],
-"exif_8h.html#a9c950d72cbf4b8cb1719d5262548510e":[2,0,2,5,73],
-"exif_8h.html#a9e0f8ee23188c536de9331752f85c9e0":[2,0,2,5,29],
-"exif_8h.html#aa089c3b9a11cccb1b40d17acbdd33b2b":[2,0,2,5,70],
-"exif_8h.html#aa112c1cb2ae9ae8ee87bad49eddd2f5c":[2,0,2,5,60],
-"exif_8h.html#aa2d9f1686c67b612aa05c252295654a4":[2,0,2,5,68],
-"exif_8h.html#aaa64c422536aea7b660704b5d4629f9a":[2,0,2,5,15],
-"exif_8h.html#aab48b12ed06473bb882adfa6a7f22b03":[2,0,2,5,12],
-"exif_8h.html#aacb4c7af73896f1a45935a9ec0f00144":[2,0,2,5,62],
-"exif_8h.html#ab05ddf1aa5a000417e086f5da7c4335b":[2,0,2,5,6],
-"exif_8h.html#ab5bb1d2f591b77011385366dc2f5f475":[2,0,2,5,3],
-"exif_8h.html#ab5d0bff69eba8f03f3a67fdd3aa91ad7":[2,0,2,5,17],
-"exif_8h.html#ab5ff37e518e03261dac779e41b0d517d":[2,0,2,5,87],
-"exif_8h.html#ab7757e7148f8c31e45d949a020ecc33b":[2,0,2,5,32],
-"exif_8h.html#abc764bbb070f84e33791d668bd5d3d1c":[2,0,2,5,64],
-"exif_8h.html#ac0aad41fe8429e9b144d04421673395f":[2,0,2,5,55],
-"exif_8h.html#ac15cbb8d5fe4f2e18f6b2c87ea8f0060":[2,0,2,5,80],
-"exif_8h.html#ac2504f686959b72e90f31d9329005f35":[2,0,2,5,63],
-"exif_8h.html#ac42c599e4731cd76bb243c6cec5eb6f8":[2,0,2,5,78],
-"exif_8h.html#ad15049fb69f487cf26b18cac44e49ff6":[2,0,2,5,13],
-"exif_8h.html#ad3280b9244c476accbab2c49523d815f":[2,0,2,5,83],
-"exif_8h.html#ad44aadef264377d255475070ad6b6cae":[2,0,2,5,30],
-"exif_8h.html#ad5552ead6451e353fdce1145102837ca":[2,0,2,5,88],
-"exif_8h.html#addf46188855a82d13afad76167627c22":[2,0,2,5,75],
-"exif_8h.html#adf62bccc61524d1df5f9a5cb4e487b57":[2,0,2,5,53],
-"exif_8h.html#ae28221d83dad5c010a5f5c491b1f0d5b":[2,0,2,5,49],
-"exif_8h.html#ae311f0ed3623f25549e1850cf31421a5":[2,0,2,5,11],
-"exif_8h.html#ae4015ea3fd30a83f0c26950fbab0e6f6":[2,0,2,5,77],
-"exif_8h.html#ae54275fcacf8c1b505709d263bc7be3b":[2,0,2,5,41],
-"exif_8h.html#ae73c660664834102714694ef8e8718a9":[2,0,2,5,52],
-"exif_8h.html#ae91050f7a8743063ffd9fde53a524939":[2,0,2,5,50],
-"exif_8h.html#aecd265cf10092d7be0dfbad7f86cab90":[2,0,2,5,36],
-"exif_8h.html#aeffb8750c4f14c983a7f12371197b7af":[2,0,2,5,48],
-"exif_8h.html#af11a064f9fb8b1da515ab036ae0f2e8d":[2,0,2,5,74],
-"exif_8h.html#af20e94de68d9d9d97e008a6a8b17950b":[2,0,2,5,44],
-"exif_8h.html#af322d4755517972166eb05d78a7e3edb":[2,0,2,5,35],
-"exif_8h.html#af695231018b054fabc282a6d8123f348":[2,0,2,5,71],
-"exif_8h.html#afca0338d1344378bf4d5fcc952884cc2":[2,0,2,5,91],
-"exif_8h.html#afca0338d1344378bf4d5fcc952884cc2a1c1c70033f3974fcd26fe85743fc676a":[2,0,2,5,91,0],
-"exif_8h.html#afca0338d1344378bf4d5fcc952884cc2a33e425b3015c0c96ff61829d0ea13654":[2,0,2,5,91,2],
-"exif_8h.html#afca0338d1344378bf4d5fcc952884cc2a3bf9bb6ffca959aa8bde29c5deccdb43":[2,0,2,5,91,9],
-"exif_8h.html#afca0338d1344378bf4d5fcc952884cc2a404e3c82444d77d65a145c020784e886":[2,0,2,5,91,1],
-"exif_8h.html#afca0338d1344378bf4d5fcc952884cc2a407b6a2b500d043867c8447c0c4aa530":[2,0,2,5,91,8],
-"exif_8h.html#afca0338d1344378bf4d5fcc952884cc2a408a8ac678f0a66e4b4b10af5ff475e1":[2,0,2,5,91,3],
-"exif_8h.html#afca0338d1344378bf4d5fcc952884cc2a570b5d7fa6c4c892914a73302381ddab":[2,0,2,5,91,10],
-"exif_8h.html#afca0338d1344378bf4d5fcc952884cc2a5b836523371f0a467ade525453148313":[2,0,2,5,91,4],
-"exif_8h.html#afca0338d1344378bf4d5fcc952884cc2a71b854114da0b48c2bdd52d9dc1fff39":[2,0,2,5,91,7],
-"exif_8h.html#afca0338d1344378bf4d5fcc952884cc2a88bade758e1d3850069e546d60289765":[2,0,2,5,91,12],
-"exif_8h.html#afca0338d1344378bf4d5fcc952884cc2a8a98afdc1e7b49cabfb6ee2c242f6da8":[2,0,2,5,91,5],
-"exif_8h.html#afca0338d1344378bf4d5fcc952884cc2ab5fc5e270e9f1cd6b22a8dd000bcb12d":[2,0,2,5,91,6],
-"exif_8h.html#afca0338d1344378bf4d5fcc952884cc2ad63bb1af021a218f66e685683a05d73a":[2,0,2,5,91,11],
-"exif_8h.html#afd8b2bec981dfa8009883f628d05dbda":[2,0,2,5,20],
-"exif_8h.html#afe9c7579517fa2a4bf827a9f3b4a92b9":[2,0,2,5,34],
+"exif_8h.html#addf34b3ba9fb5b467384cf758966170b":[2,0,2,5,1],
+"exif_8h.html#aefbbfb47ade88403c2f07fefcb9abb25":[2,0,2,5,0],
 "exif_8h_source.html":[2,0,2,5],
 "files.html":[2,0],
 "functions.html":[1,1,0],
@@ -166,24 +63,24 @@ var NAVTREEINDEX0 =
 "gamma_8h_source.html":[2,0,2,7],
 "globals.html":[2,1,0],
 "globals.html":[2,1,0,0],
-"globals_0x62.html":[2,1,0,1],
-"globals_0x63.html":[2,1,0,2],
-"globals_0x64.html":[2,1,0,3],
-"globals_0x66.html":[2,1,0,4],
-"globals_0x67.html":[2,1,0,5],
-"globals_0x68.html":[2,1,0,6],
-"globals_0x70.html":[2,1,0,7],
-"globals_0x73.html":[2,1,0,8],
+"globals_b.html":[2,1,0,1],
+"globals_c.html":[2,1,0,2],
+"globals_d.html":[2,1,0,3],
 "globals_defs.html":[2,1,6],
 "globals_enum.html":[2,1,4],
 "globals_eval.html":[2,1,5],
+"globals_f.html":[2,1,0,4],
 "globals_func.html":[2,1,1],
 "globals_func.html":[2,1,1,0],
-"globals_func_0x64.html":[2,1,1,1],
-"globals_func_0x66.html":[2,1,1,2],
-"globals_func_0x67.html":[2,1,1,3],
-"globals_func_0x70.html":[2,1,1,4],
-"globals_func_0x73.html":[2,1,1,5],
+"globals_func_d.html":[2,1,1,1],
+"globals_func_f.html":[2,1,1,2],
+"globals_func_g.html":[2,1,1,3],
+"globals_func_p.html":[2,1,1,4],
+"globals_func_s.html":[2,1,1,5],
+"globals_g.html":[2,1,0,5],
+"globals_h.html":[2,1,0,6],
+"globals_p.html":[2,1,0,7],
+"globals_s.html":[2,1,0,8],
 "globals_type.html":[2,1,3],
 "globals_vars.html":[2,1,2],
 "gphoto2-abilities-list_8c.html":[2,0,2,8],
@@ -249,5 +146,108 @@ var NAVTREEINDEX0 =
 "gphoto2-abilities-list_8h.html#af5705e04f9b4996bdb37675fcde7126e":[2,0,1,0,6],
 "gphoto2-abilities-list_8h.html#af5705e04f9b4996bdb37675fcde7126ea3011adb79ee494e5d9b2329641af8f6c":[2,0,1,0,6,1],
 "gphoto2-abilities-list_8h.html#af5705e04f9b4996bdb37675fcde7126ea994862eaf8128a5b062b909b82112e0f":[2,0,1,0,6,0],
-"gphoto2-abilities-list_8h_source.html":[2,0,1,0]
+"gphoto2-abilities-list_8h_source.html":[2,0,1,0],
+"gphoto2-camera_8c.html":[2,0,2,9],
+"gphoto2-camera_8c.html#a01d8d222d4b7f090f678080b8ce9998e":[2,0,2,9,42],
+"gphoto2-camera_8c.html#a068405c418270c7c63ab9fdc3c0ae620":[2,0,2,9,37],
+"gphoto2-camera_8c.html#a0a46cbd79e1a634acebec4380cee6c5b":[2,0,2,9,33],
+"gphoto2-camera_8c.html#a0b289e071be43bfeb6e65757cc274dbf":[2,0,2,9,46],
+"gphoto2-camera_8c.html#a0c61c3d62a6bb6daecbadbffa06cf3fb":[2,0,2,9,25],
+"gphoto2-camera_8c.html#a0cdf2043359617d5132665c36fc557d0":[2,0,2,9,26],
+"gphoto2-camera_8c.html#a0fc2c594397f144a134074757e9dfab1":[2,0,2,9,48],
+"gphoto2-camera_8c.html#a115dd6a6dd9d7a249f6374a7c06deef5":[2,0,2,9,11],
+"gphoto2-camera_8c.html#a11f3855eef4f009701b008908fc78608":[2,0,2,9,30],
+"gphoto2-camera_8c.html#a1a66b26a0456f3d265051c4018f67208":[2,0,2,9,24],
+"gphoto2-camera_8c.html#a1c1ad4e0cc48fec22aaddbba147975c8":[2,0,2,9,23],
+"gphoto2-camera_8c.html#a240f8cc35944b01cce71609c265fda3a":[2,0,2,9,32],
+"gphoto2-camera_8c.html#a2413621dbe10bd9d91fdd5fd82c81618":[2,0,2,9,7],
+"gphoto2-camera_8c.html#a262b1bc840d62b12605e3acc543f714d":[2,0,2,9,21],
+"gphoto2-camera_8c.html#a32a3cf3d9dd914f5aeeca5423c157934":[2,0,2,9,1],
+"gphoto2-camera_8c.html#a32cfd1eaec837dd43676eb211fa68cdb":[2,0,2,9,35],
+"gphoto2-camera_8c.html#a449781f840d1a82e56f424d33371c511":[2,0,2,9,44],
+"gphoto2-camera_8c.html#a456172175ee1829ef172ee9c747e850d":[2,0,2,9,20],
+"gphoto2-camera_8c.html#a4954f9a8b7eaf2df232babe91f93fca7":[2,0,2,9,6],
+"gphoto2-camera_8c.html#a5d5649f8c672a52800d0723bf29f33fa":[2,0,2,9,53],
+"gphoto2-camera_8c.html#a5f80e8482ab93869489531a8c7ce7006":[2,0,2,9,15],
+"gphoto2-camera_8c.html#a6027cb54859c035ce943cf1c3e06121a":[2,0,2,9,54],
+"gphoto2-camera_8c.html#a640b436ef19db8154283cc3044fb1d0a":[2,0,2,9,51],
+"gphoto2-camera_8c.html#a6a3aa30acd4bbe74087ce0fbcb9ea3a9":[2,0,2,9,55],
+"gphoto2-camera_8c.html#a6b6669216aeae67304649edd42db605d":[2,0,2,9,28],
+"gphoto2-camera_8c.html#a6d95c83814161ccd8f4cc1e86233c9d4":[2,0,2,9,52],
+"gphoto2-camera_8c.html#a6f19c4ea385641fb972e779badf48ae1":[2,0,2,9,19],
+"gphoto2-camera_8c.html#a75278405e7f034d2b1af80bfd94675fe":[2,0,2,9,14],
+"gphoto2-camera_8c.html#a78ae1a19cc0fb4d94026f82497381124":[2,0,2,9,31],
+"gphoto2-camera_8c.html#a7a2b16620e8dcd0efbd6f767188d9162":[2,0,2,9,40],
+"gphoto2-camera_8c.html#a7dc2b5ed66b61b881caf7436cb05ded0":[2,0,2,9,27],
+"gphoto2-camera_8c.html#a7de1aba49ce9fb5d84464417da3352e6":[2,0,2,9,8],
+"gphoto2-camera_8c.html#a7fb0a84c4d54825143b3eee22e81d3ce":[2,0,2,9,10],
+"gphoto2-camera_8c.html#a83b8be0887dede025766d25e2bb884c6":[2,0,2,9,13],
+"gphoto2-camera_8c.html#a8501471508eb438eb07e9cf034dc498c":[2,0,2,9,5],
+"gphoto2-camera_8c.html#a87bb8878064d7c4a98f1be7cedf7fd3c":[2,0,2,9,47],
+"gphoto2-camera_8c.html#a8807273e062a649fe96c14f54e436bca":[2,0,2,9,4],
+"gphoto2-camera_8c.html#a8fa6903e3bf0ab26edc4e915512aa44f":[2,0,2,9,17],
+"gphoto2-camera_8c.html#a95f595a6d9bfe68d99419a0087363f89":[2,0,2,9,45],
+"gphoto2-camera_8c.html#a969c10fd16501f62f0e3a276d237764a":[2,0,2,9,36],
+"gphoto2-camera_8c.html#aa3dd64d491735a55bcab15d41b9113c3":[2,0,2,9,29],
+"gphoto2-camera_8c.html#ab0e3da4a22b7b71ec36e58157c868a9e":[2,0,2,9,41],
+"gphoto2-camera_8c.html#abe944d32d0d1d16ab7519111476a8b57":[2,0,2,9,9],
+"gphoto2-camera_8c.html#abf808fe8f9c7b0dbf9f9c4b6d5aef4b2":[2,0,2,9,38],
+"gphoto2-camera_8c.html#ac05b040056bfb8e0517570d4fd87eb1e":[2,0,2,9,3],
+"gphoto2-camera_8c.html#accaa70d614800dac941e543187c9712d":[2,0,2,9,18],
+"gphoto2-camera_8c.html#ad24abc7110e1bdf384dc2ef2b63e5d07":[2,0,2,9,12],
+"gphoto2-camera_8c.html#ad5add695de4a33b6c5cbb8be32bf9af7":[2,0,2,9,39],
+"gphoto2-camera_8c.html#ad89d6ee1c35f5ee399e89ecaeac6bd61":[2,0,2,9,43],
+"gphoto2-camera_8c.html#add6dfc1077058ff26d79cdb18099d58a":[2,0,2,9,2],
+"gphoto2-camera_8c.html#adda54321b1947b711d345936041f80c7":[2,0,2,9,22],
+"gphoto2-camera_8c.html#ae231c37c434852418e308cda85f262e9":[2,0,2,9,49],
+"gphoto2-camera_8c.html#ae7b6050bb4bc7a697f9e07253c27710f":[2,0,2,9,16],
+"gphoto2-camera_8c.html#ae87f24abbc6ee895867331c64e6986cf":[2,0,2,9,34],
+"gphoto2-camera_8c.html#af2e448cda5a2a1637d497fec7b89c44f":[2,0,2,9,50],
+"gphoto2-camera_8h.html":[2,0,1,1],
+"gphoto2-camera_8h.html#a01d8d222d4b7f090f678080b8ce9998e":[2,0,1,1,53],
+"gphoto2-camera_8h.html#a068405c418270c7c63ab9fdc3c0ae620":[2,0,1,1,48],
+"gphoto2-camera_8h.html#a0a46cbd79e1a634acebec4380cee6c5b":[2,0,1,1,44],
+"gphoto2-camera_8h.html#a0b289e071be43bfeb6e65757cc274dbf":[2,0,1,1,57],
+"gphoto2-camera_8h.html#a0c61c3d62a6bb6daecbadbffa06cf3fb":[2,0,1,1,36],
+"gphoto2-camera_8h.html#a0cdf2043359617d5132665c36fc557d0":[2,0,1,1,37],
+"gphoto2-camera_8h.html#a0fc2c594397f144a134074757e9dfab1":[2,0,1,1,59],
+"gphoto2-camera_8h.html#a11f3855eef4f009701b008908fc78608":[2,0,1,1,41],
+"gphoto2-camera_8h.html#a1a66b26a0456f3d265051c4018f67208":[2,0,1,1,35],
+"gphoto2-camera_8h.html#a1c1ad4e0cc48fec22aaddbba147975c8":[2,0,1,1,34],
+"gphoto2-camera_8h.html#a240f8cc35944b01cce71609c265fda3a":[2,0,1,1,43],
+"gphoto2-camera_8h.html#a262b1bc840d62b12605e3acc543f714d":[2,0,1,1,32],
+"gphoto2-camera_8h.html#a26351cb024be661dd0cb7e48afd8bc8a":[2,0,1,1,17],
+"gphoto2-camera_8h.html#a26facb6ff3b8a39d1968fa23d950f9de":[2,0,1,1,19],
+"gphoto2-camera_8h.html#a298fe44a034ee548ba07d29a943c8256":[2,0,1,1,9],
+"gphoto2-camera_8h.html#a2b4c42276b047ed5b33ef5646db8becc":[2,0,1,1,23],
+"gphoto2-camera_8h.html#a2ca051bcc451341fd0c93b64f521bfaf":[2,0,1,1,18],
+"gphoto2-camera_8h.html#a2ca795a13c68fd59a19b2eb461e83a00":[2,0,1,1,15],
+"gphoto2-camera_8h.html#a32cfd1eaec837dd43676eb211fa68cdb":[2,0,1,1,46],
+"gphoto2-camera_8h.html#a40a20fdc154b0631cbd3a0a95d1ae165":[2,0,1,1,14],
+"gphoto2-camera_8h.html#a438ab2ac60ad5d5ced30e4201476800b":[2,0,1,1,26],
+"gphoto2-camera_8h.html#a438ab2ac60ad5d5ced30e4201476800ba0575ebbc9e85ac5cd424ef20a77b7162":[2,0,1,1,26,2],
+"gphoto2-camera_8h.html#a438ab2ac60ad5d5ced30e4201476800ba0f9561e9d66ea77a89eb472d75ba11e2":[2,0,1,1,26,3],
+"gphoto2-camera_8h.html#a438ab2ac60ad5d5ced30e4201476800ba6201d8e02b4a46ee7c67d7478b8b7658":[2,0,1,1,26,1],
+"gphoto2-camera_8h.html#a438ab2ac60ad5d5ced30e4201476800bac818979d0da4b73b7de8e0ad0cffcf2f":[2,0,1,1,26,0],
+"gphoto2-camera_8h.html#a438ab2ac60ad5d5ced30e4201476800bafd65c3c57e22b937ad1d4a2663ef4070":[2,0,1,1,26,4],
+"gphoto2-camera_8h.html#a449781f840d1a82e56f424d33371c511":[2,0,1,1,55],
+"gphoto2-camera_8h.html#a456172175ee1829ef172ee9c747e850d":[2,0,1,1,31],
+"gphoto2-camera_8h.html#a5d5649f8c672a52800d0723bf29f33fa":[2,0,1,1,64],
+"gphoto2-camera_8h.html#a5ef187a092edd693b3d01ad8304728fb":[2,0,1,1,4],
+"gphoto2-camera_8h.html#a6027cb54859c035ce943cf1c3e06121a":[2,0,1,1,65],
+"gphoto2-camera_8h.html#a640b436ef19db8154283cc3044fb1d0a":[2,0,1,1,62],
+"gphoto2-camera_8h.html#a6a3aa30acd4bbe74087ce0fbcb9ea3a9":[2,0,1,1,66],
+"gphoto2-camera_8h.html#a6a66768c14ce761d6810f64572c79ec1":[2,0,1,1,25],
+"gphoto2-camera_8h.html#a6a66768c14ce761d6810f64572c79ec1a4e6ca859490742a8435d04223c2a0056":[2,0,1,1,25,0],
+"gphoto2-camera_8h.html#a6a66768c14ce761d6810f64572c79ec1ae2166855f1a96d61dc4da6cef03bce4d":[2,0,1,1,25,2],
+"gphoto2-camera_8h.html#a6a66768c14ce761d6810f64572c79ec1afa8c68bfa3fa365ad562ca6929e6cee7":[2,0,1,1,25,1],
+"gphoto2-camera_8h.html#a6b6669216aeae67304649edd42db605d":[2,0,1,1,39],
+"gphoto2-camera_8h.html#a6c72255946125f3aec9f673080f401d3":[2,0,1,1,21],
+"gphoto2-camera_8h.html#a6d95c83814161ccd8f4cc1e86233c9d4":[2,0,1,1,63],
+"gphoto2-camera_8h.html#a6f19c4ea385641fb972e779badf48ae1":[2,0,1,1,30],
+"gphoto2-camera_8h.html#a78ae1a19cc0fb4d94026f82497381124":[2,0,1,1,42],
+"gphoto2-camera_8h.html#a7a2b16620e8dcd0efbd6f767188d9162":[2,0,1,1,51],
+"gphoto2-camera_8h.html#a7dc2b5ed66b61b881caf7436cb05ded0":[2,0,1,1,38],
+"gphoto2-camera_8h.html#a87bb8878064d7c4a98f1be7cedf7fd3c":[2,0,1,1,58],
+"gphoto2-camera_8h.html#a8fa6903e3bf0ab26edc4e915512aa44f":[2,0,1,1,28]
 };
