@@ -1,108 +1,5 @@
 var NAVTREEINDEX2 =
 {
-"gphoto2-file_8h.html#ab9f339bdf374343272c62d2352753d69a5f9e4fc5c19d2f49b1539d61ebc7d824":[2,0,1,3,29,5],
-"gphoto2-file_8h.html#ab9f339bdf374343272c62d2352753d69a8e7f28766023ea910ca6e34f4745f915":[2,0,1,3,29,3],
-"gphoto2-file_8h.html#ab9f339bdf374343272c62d2352753d69aa8534dad4e3b2024cf8eae58fdbe940f":[2,0,1,3,29,1],
-"gphoto2-file_8h.html#ab9f339bdf374343272c62d2352753d69adfc3456d99351d80f6d514cd130f8c62":[2,0,1,3,29,4],
-"gphoto2-file_8h.html#ab9f339bdf374343272c62d2352753d69af9deb2f536e56d6546239f785c29f7c8":[2,0,1,3,29,2],
-"gphoto2-file_8h.html#aba965b1a676ea68194cb4052b3dea00d":[2,0,1,3,38],
-"gphoto2-file_8h.html#abfdcea806c848d1e959108b69642d3f9":[2,0,1,3,4],
-"gphoto2-file_8h.html#ac0058da71651fd4068306be65fa680cc":[2,0,1,3,35],
-"gphoto2-file_8h.html#ac31856165a1b0fb6e64b06a5a47b8cc7":[2,0,1,3,34],
-"gphoto2-file_8h.html#aca2b7ed7d1b91fcdb0578ee71142a101":[2,0,1,3,45],
-"gphoto2-file_8h.html#ad3ad5261f1b3eca778263e13db5ff308":[2,0,1,3,18],
-"gphoto2-file_8h.html#ad6107fa3f070c7f46bc2903275add9cc":[2,0,1,3,15],
-"gphoto2-file_8h.html#ad907d4ac340eaa9e2371726df5aa515a":[2,0,1,3,2],
-"gphoto2-file_8h.html#adb84f867bcc3df8e979aea52b06dbdef":[2,0,1,3,6],
-"gphoto2-file_8h.html#add71180e16fc7a5b933cef7b0cd989d6":[2,0,1,3,24],
-"gphoto2-file_8h.html#ade7379a5b38f498b2c550c45f58b400d":[2,0,1,3,25],
-"gphoto2-file_8h.html#ae17d5cf6651a094da8a035a5aec477e4":[2,0,1,3,8],
-"gphoto2-file_8h.html#ae2f0802d187957c104a3bb6925edc95a":[2,0,1,3,49],
-"gphoto2-file_8h.html#ae4575bab836285ea2c0765dec0660929":[2,0,1,3,12],
-"gphoto2-file_8h.html#ae4c27a5589e08db1a4bc37b825dec842":[2,0,1,3,28],
-"gphoto2-file_8h.html#ae4c27a5589e08db1a4bc37b825dec842a885208212a9c765895d48a3dddd54470":[2,0,1,3,28,1],
-"gphoto2-file_8h.html#ae4c27a5589e08db1a4bc37b825dec842add357028781a405fed99210f321aa19f":[2,0,1,3,28,0],
-"gphoto2-file_8h.html#ae4c27a5589e08db1a4bc37b825dec842af8d7ad7cfc3baaa5135ca835d4e388c7":[2,0,1,3,28,2],
-"gphoto2-file_8h.html#ae6f2318d561ce3ff3a37a1145a0e1de6":[2,0,1,3,19],
-"gphoto2-file_8h.html#af0d1d638d7a58ae9591be458eeb13c72":[2,0,1,3,41],
-"gphoto2-file_8h.html#afe87b1e2f9df858f3737bb0d603a0d6e":[2,0,1,3,31],
-"gphoto2-file_8h_source.html":[2,0,1,3],
-"gphoto2-filesys_8c.html":[2,0,2,13],
-"gphoto2-filesys_8c.html#a083ea3fd7f794f6de09c1c51ba142572":[2,0,2,13,29],
-"gphoto2-filesys_8c.html#a08fa6e05d77adce0b6be853c226dedaa":[2,0,2,13,27],
-"gphoto2-filesys_8c.html#a09a92d2b9ed9744765bb3216f986a794":[2,0,2,13,20],
-"gphoto2-filesys_8c.html#a0e785e85f4a199ee87dfd7604ad8d45a":[2,0,2,13,26],
-"gphoto2-filesys_8c.html#a115dd6a6dd9d7a249f6374a7c06deef5":[2,0,2,13,11],
-"gphoto2-filesys_8c.html#a2cd5449536c57828b6873e635b51de72":[2,0,2,13,7],
-"gphoto2-filesys_8c.html#a32a3cf3d9dd914f5aeeca5423c157934":[2,0,2,13,3],
-"gphoto2-filesys_8c.html#a387fbb724c3c697e6eb2bd81a9a0e075":[2,0,2,13,8],
-"gphoto2-filesys_8c.html#a3acffbd305ee72dcd4593c0d8af64a4f":[2,0,2,13,14],
-"gphoto2-filesys_8c.html#a3c12781d176e73fb9e8795d29e64f56e":[2,0,2,13,36],
-"gphoto2-filesys_8c.html#a3ffbe7ac58a11c688edd98369741f828":[2,0,2,13,44],
-"gphoto2-filesys_8c.html#a42bad7d5fc4433d353f1d336f575c340":[2,0,2,13,34],
-"gphoto2-filesys_8c.html#a46c32fb69d164f5f877338014825d318":[2,0,2,13,17],
-"gphoto2-filesys_8c.html#a4d1424f4d45018dc892a2da792822f0c":[2,0,2,13,24],
-"gphoto2-filesys_8c.html#a4e4ea8548673cc56c465ee447dd916f3":[2,0,2,13,45],
-"gphoto2-filesys_8c.html#a57f7b7038489eadd5a78787d6cfe8d66":[2,0,2,13,41],
-"gphoto2-filesys_8c.html#a5f80e8482ab93869489531a8c7ce7006":[2,0,2,13,18],
-"gphoto2-filesys_8c.html#a6b6fc659abe86a1724fe6600d112931f":[2,0,2,13,23],
-"gphoto2-filesys_8c.html#a6f6d981b8ab1273e8048df66670782ab":[2,0,2,13,43],
-"gphoto2-filesys_8c.html#a721a17344ce386f2aa6c408cbe5b027d":[2,0,2,13,9],
-"gphoto2-filesys_8c.html#a75278405e7f034d2b1af80bfd94675fe":[2,0,2,13,15],
-"gphoto2-filesys_8c.html#a76d3271d228bb3af694e9b846dda71e3":[2,0,2,13,6],
-"gphoto2-filesys_8c.html#a7bbfa59b2587d36fa5be529c788f9585":[2,0,2,13,28],
-"gphoto2-filesys_8c.html#a7ee1e023cac99c0e96d28954bd626b19":[2,0,2,13,42],
-"gphoto2-filesys_8c.html#a7fdf2e5f1c7fda4b0f7f58f45a33c71c":[2,0,2,13,22],
-"gphoto2-filesys_8c.html#a83b8be0887dede025766d25e2bb884c6":[2,0,2,13,13],
-"gphoto2-filesys_8c.html#a97c3a1cb9996eb8319d232023209bf19":[2,0,2,13,32],
-"gphoto2-filesys_8c.html#aa6cd62861b01c157efcdf25dd2753576":[2,0,2,13,25],
-"gphoto2-filesys_8c.html#aafe39aadfe2259eb5bc3d3de0dd864cc":[2,0,2,13,21],
-"gphoto2-filesys_8c.html#ab22748e14f4e4d0492c4ddeeec557e70":[2,0,2,13,35],
-"gphoto2-filesys_8c.html#ac58c62bed856f6b143aaa776d74b5705":[2,0,2,13,30],
-"gphoto2-filesys_8c.html#ad24abc7110e1bdf384dc2ef2b63e5d07":[2,0,2,13,12],
-"gphoto2-filesys_8c.html#ad3d8a3bd0c0b677acef144f2c2ef6d73":[2,0,2,13,4],
-"gphoto2-filesys_8c.html#ad6a4885b641b284f22ef55ad3ec8aac2":[2,0,2,13,19],
-"gphoto2-filesys_8c.html#add6dfc1077058ff26d79cdb18099d58a":[2,0,2,13,5],
-"gphoto2-filesys_8c.html#ae1e4bab15af84be9873bbd14b383da25":[2,0,2,13,38],
-"gphoto2-filesys_8c.html#ae6106ac2f70f59b50525a8de870ec25b":[2,0,2,13,33],
-"gphoto2-filesys_8c.html#ae688d728e1acdfe5988c7db45d6f0166":[2,0,2,13,16],
-"gphoto2-filesys_8c.html#aed55d9d55663c0cc58f002a176ad2aa4":[2,0,2,13,39],
-"gphoto2-filesys_8c.html#af452484585d434e4101a92ef4ffd55ca":[2,0,2,13,10],
-"gphoto2-filesys_8c.html#af55d08507d98adf2b02d1efe5f78623d":[2,0,2,13,40],
-"gphoto2-filesys_8c.html#af706b65998fe5f7c7bebd386b941c778":[2,0,2,13,31],
-"gphoto2-filesys_8c.html#af9cb8b2135e3eaf71ee864fed2d56212":[2,0,2,13,37],
-"gphoto2-filesys_8h.html":[2,0,1,4],
-"gphoto2-filesys_8h.html#a083ea3fd7f794f6de09c1c51ba142572":[2,0,1,4,38],
-"gphoto2-filesys_8h.html#a08fa6e05d77adce0b6be853c226dedaa":[2,0,1,4,36],
-"gphoto2-filesys_8h.html#a0db69e33a547a0ba2706f8cf386a29eb":[2,0,1,4,12],
-"gphoto2-filesys_8h.html#a0e785e85f4a199ee87dfd7604ad8d45a":[2,0,1,4,35],
-"gphoto2-filesys_8h.html#a1a9fdae1cac2fbf67abb9ad360ec2bc4":[2,0,1,4,10],
-"gphoto2-filesys_8h.html#a2e0fe092c4fd0e08f28018503c985def":[2,0,1,4,24],
-"gphoto2-filesys_8h.html#a2e0fe092c4fd0e08f28018503c985defa03a88392838e9aed558b03c1753f7c3c":[2,0,1,4,24,3],
-"gphoto2-filesys_8h.html#a2e0fe092c4fd0e08f28018503c985defa17ee5aed70a5a7ea58b148b95f9f6b4b":[2,0,1,4,24,2],
-"gphoto2-filesys_8h.html#a2e0fe092c4fd0e08f28018503c985defa19ee3c09396fb571102f8f8603b2ba07":[2,0,1,4,24,1],
-"gphoto2-filesys_8h.html#a2e0fe092c4fd0e08f28018503c985defae8c0a7b576f9e7a136db4a8098dc2e2d":[2,0,1,4,24,0],
-"gphoto2-filesys_8h.html#a3c12781d176e73fb9e8795d29e64f56e":[2,0,1,4,45],
-"gphoto2-filesys_8h.html#a3ffbe7ac58a11c688edd98369741f828":[2,0,1,4,53],
-"gphoto2-filesys_8h.html#a42bad7d5fc4433d353f1d336f575c340":[2,0,1,4,43],
-"gphoto2-filesys_8h.html#a42d72c58efd503dc56e35b38877fe06d":[2,0,1,4,19],
-"gphoto2-filesys_8h.html#a4d1424f4d45018dc892a2da792822f0c":[2,0,1,4,33],
-"gphoto2-filesys_8h.html#a4e4ea8548673cc56c465ee447dd916f3":[2,0,1,4,54],
-"gphoto2-filesys_8h.html#a57f7b7038489eadd5a78787d6cfe8d66":[2,0,1,4,50],
-"gphoto2-filesys_8h.html#a5e8cab7c2e27696f6299860669f77268":[2,0,1,4,14],
-"gphoto2-filesys_8h.html#a6b6fc659abe86a1724fe6600d112931f":[2,0,1,4,32],
-"gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907":[2,0,1,4,23],
-"gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907a02d7794e26a9b4333cec58a82ac31d61":[2,0,1,4,23,3],
-"gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907a0a0190e06a2d872347d099378cb20b6a":[2,0,1,4,23,4],
-"gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907a259e66be4884ad572ca319e0c510d52f":[2,0,1,4,23,1],
-"gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907a6603c2d07d8d87bfc5378f99f0869665":[2,0,1,4,23,6],
-"gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907a70c192de7c121febde90af7e117c0eed":[2,0,1,4,23,0],
-"gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907a7c19dc619e18629df027df1f8aaa1035":[2,0,1,4,23,8],
-"gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907a7f0cc4ba19d9f92f2e8e12de6580f47b":[2,0,1,4,23,2],
-"gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907a9277302e076066219975e49bbc574600":[2,0,1,4,23,7],
-"gphoto2-filesys_8h.html#a6ee15bfa0ff8bf74872e13a87e1a4907a9ed3048a35c2f6a59d6e89e52f24b1a5":[2,0,1,4,23,5],
-"gphoto2-filesys_8h.html#a6f6d981b8ab1273e8048df66670782ab":[2,0,1,4,52],
-"gphoto2-filesys_8h.html#a75d0f5c804d7ea9274729202913aa472":[2,0,1,4,11],
 "gphoto2-filesys_8h.html#a7bbfa59b2587d36fa5be529c788f9585":[2,0,1,4,37],
 "gphoto2-filesys_8h.html#a7e4db0952402346bf8c8c6a51581efec":[2,0,1,4,17],
 "gphoto2-filesys_8h.html#a7ee1e023cac99c0e96d28954bd626b19":[2,0,1,4,51],
@@ -249,5 +146,108 @@ var NAVTREEINDEX2 =
 "gphoto2-port-info-list_8h.html#a4621674c74440cc4d68d24e45fc9f148":[2,0,3,0,0,18],
 "gphoto2-port-info-list_8h.html#a541be7394f5ab48304fe48e5a6cec757":[2,0,3,0,0,0],
 "gphoto2-port-info-list_8h.html#a61b08d6eddea3c0e0c51869363632cea":[2,0,3,0,0,11],
-"gphoto2-port-info-list_8h.html#a625daffc59c3fd87b9f3b73b129f3b96":[2,0,3,0,0,3]
+"gphoto2-port-info-list_8h.html#a625daffc59c3fd87b9f3b73b129f3b96":[2,0,3,0,0,3],
+"gphoto2-port-info-list_8h.html#a70f65ef80a59174adfa52c3e199752d4":[2,0,3,0,0,6],
+"gphoto2-port-info-list_8h.html#a85b97ad361854a8076b61be70fe85304":[2,0,3,0,0,10],
+"gphoto2-port-info-list_8h.html#a8677c876b22dc6b4545e92fda9810ed4":[2,0,3,0,0,15],
+"gphoto2-port-info-list_8h.html#a9736997967ed0bdb2ac0ace4e02df531":[2,0,3,0,0,5],
+"gphoto2-port-info-list_8h.html#a9810bfba9c986f4d102cfaf649199f21":[2,0,3,0,0,4],
+"gphoto2-port-info-list_8h.html#ab60c983825bfa2b6aa2fcb1e1a32b08f":[2,0,3,0,0,9],
+"gphoto2-port-info-list_8h.html#abd6e63f271c916e041be85e7b279374a":[2,0,3,0,0,1],
+"gphoto2-port-info-list_8h.html#acbb59be40d7a67a13b7ffd26dcd3e9bb":[2,0,3,0,0,7],
+"gphoto2-port-info-list_8h.html#ad925c660b558db82d22c62e8ae09c756":[2,0,3,0,0,13],
+"gphoto2-port-info-list_8h.html#ae2595948920409d2002d879475d6e350":[2,0,3,0,0,20],
+"gphoto2-port-info-list_8h.html#af1f1553e664584f74724a8825829bc09":[2,0,3,0,0,16],
+"gphoto2-port-info-list_8h_source.html":[2,0,3,0,0],
+"gphoto2-port-info_8h.html":[2,0,3,1,1],
+"gphoto2-port-info_8h_source.html":[2,0,3,1,1],
+"gphoto2-port-library_8h.html":[2,0,3,0,1],
+"gphoto2-port-library_8h.html#a1691b9d2ab5502d0dabec4445ebf2bef":[2,0,3,0,1,5],
+"gphoto2-port-library_8h.html#a548bbb8e99c1aa3a4a8ca2ccd6b3b15f":[2,0,3,0,1,2],
+"gphoto2-port-library_8h.html#a677295b647d8d00d3cdb4caa14e36aae":[2,0,3,0,1,4],
+"gphoto2-port-library_8h.html#a9e13d12e5c9833e6600b5c05c7e9bea7":[2,0,3,0,1,7],
+"gphoto2-port-library_8h.html#aa9e5f9918113e292954e61d4183bf98b":[2,0,3,0,1,3],
+"gphoto2-port-library_8h.html#af4a2e56a43c90ed9d4766c9ba6919cc1":[2,0,3,0,1,6],
+"gphoto2-port-library_8h.html#af9381a47a6db50ab2f3511d0aa35cbe1":[2,0,3,0,1,1],
+"gphoto2-port-library_8h_source.html":[2,0,3,0,1],
+"gphoto2-port-log_8c.html":[2,0,3,1,2],
+"gphoto2-port-log_8c.html#a07601ec204167a55885e02b80edd3fcf":[2,0,3,1,2,16],
+"gphoto2-port-log_8c.html#a0b14529482e5bc725bcc003583337ea7":[2,0,3,1,2,14],
+"gphoto2-port-log_8c.html#a25d3dff9fc4f2a43d2fb7c992d46e24b":[2,0,3,1,2,4],
+"gphoto2-port-log_8c.html#a2bdf0f15991734c7a632c10714553277":[2,0,3,1,2,5],
+"gphoto2-port-log_8c.html#a32a3cf3d9dd914f5aeeca5423c157934":[2,0,3,1,2,1],
+"gphoto2-port-log_8c.html#a425183fc022968cf26219b38421b42ee":[2,0,3,1,2,9],
+"gphoto2-port-log_8c.html#a4d62d7864045598068173b20f87380ea":[2,0,3,1,2,6],
+"gphoto2-port-log_8c.html#a5e9bad704f3b065a2d5b653c7516a1ee":[2,0,3,1,2,17],
+"gphoto2-port-log_8c.html#a75278405e7f034d2b1af80bfd94675fe":[2,0,3,1,2,10],
+"gphoto2-port-log_8c.html#a77325969d9eb7e1b9c2285233c7b3862":[2,0,3,1,2,11],
+"gphoto2-port-log_8c.html#aa670fefafc10fc80dba398d2050ce62c":[2,0,3,1,2,3],
+"gphoto2-port-log_8c.html#aad08200a2e1b98c54ba32e8c80bfac6c":[2,0,3,1,2,12],
+"gphoto2-port-log_8c.html#ac724677ed0dfe9431fac69c30e2cb39b":[2,0,3,1,2,15],
+"gphoto2-port-log_8c.html#acb3fc0f7a49dd49fa8bdbe4cdaacdd0a":[2,0,3,1,2,13],
+"gphoto2-port-log_8c.html#accc780c98fc95b8ddce8f259c1575745":[2,0,3,1,2,7],
+"gphoto2-port-log_8c.html#ad3d8a3bd0c0b677acef144f2c2ef6d73":[2,0,3,1,2,2],
+"gphoto2-port-log_8c.html#ae21578f6dac5be34d83475a83e271d73":[2,0,3,1,2,8],
+"gphoto2-port-log_8h.html":[2,0,3,0,2],
+"gphoto2-port-log_8h.html#a07601ec204167a55885e02b80edd3fcf":[2,0,3,0,2,8],
+"gphoto2-port-log_8h.html#a0b14529482e5bc725bcc003583337ea7":[2,0,3,0,2,6],
+"gphoto2-port-log_8h.html#a4ca34ac78083b2afae39d798cb32353b":[2,0,3,0,2,1],
+"gphoto2-port-log_8h.html#a77325969d9eb7e1b9c2285233c7b3862":[2,0,3,0,2,3],
+"gphoto2-port-log_8h.html#aad08200a2e1b98c54ba32e8c80bfac6c":[2,0,3,0,2,4],
+"gphoto2-port-log_8h.html#ab9d873393f29f25bb32cb8fea18e0024":[2,0,3,0,2,0],
+"gphoto2-port-log_8h.html#abd2f5081afa2596ee01a61415fcdb06b":[2,0,3,0,2,2],
+"gphoto2-port-log_8h.html#abd2f5081afa2596ee01a61415fcdb06ba055df478ccbb83e8b7c9c2ac9ee4a65c":[2,0,3,0,2,2,1],
+"gphoto2-port-log_8h.html#abd2f5081afa2596ee01a61415fcdb06ba1fbaa945332b1e324217c2a4e27015dd":[2,0,3,0,2,2,0],
+"gphoto2-port-log_8h.html#abd2f5081afa2596ee01a61415fcdb06bab7502e71c4972bf803722a33b99be75f":[2,0,3,0,2,2,3],
+"gphoto2-port-log_8h.html#abd2f5081afa2596ee01a61415fcdb06badfd0d1ea537692a3dd8acc3b5675c9d2":[2,0,3,0,2,2,2],
+"gphoto2-port-log_8h.html#ac724677ed0dfe9431fac69c30e2cb39b":[2,0,3,0,2,7],
+"gphoto2-port-log_8h.html#acb3fc0f7a49dd49fa8bdbe4cdaacdd0a":[2,0,3,0,2,5],
+"gphoto2-port-log_8h_source.html":[2,0,3,0,2],
+"gphoto2-port-portability_8c.html":[2,0,3,1,3],
+"gphoto2-port-portability_8c.html#a523999a1e3fa0730e1d8b42d25dab59a":[2,0,3,1,3,3],
+"gphoto2-port-portability_8c.html#a6ec959385961156fcad1f536c821cbfd":[2,0,3,1,3,1],
+"gphoto2-port-portability_8c.html#aaf6f3209745f25e3bd313a85cdadf58e":[2,0,3,1,3,0],
+"gphoto2-port-portability_8c.html#ac84c553de1fe1dc44b02282fef9203c0":[2,0,3,1,3,5],
+"gphoto2-port-portability_8c.html#ac885311c4ead0f88c61aa77b90e88a6f":[2,0,3,1,3,4],
+"gphoto2-port-portability_8c.html#acb14f7bb33337a63652badd042f22b11":[2,0,3,1,3,6],
+"gphoto2-port-portability_8c.html#acedd7480936743544a24f462921d3420":[2,0,3,1,3,2],
+"gphoto2-port-portability_8c.html#afd709df94228f3daafefc27cfa84a6ad":[2,0,3,1,3,7],
+"gphoto2-port-portability_8h_source.html":[2,0,3,0,3],
+"gphoto2-port-result_8c.html":[2,0,3,1,4],
+"gphoto2-port-result_8c.html#a115dd6a6dd9d7a249f6374a7c06deef5":[2,0,3,1,4,2],
+"gphoto2-port-result_8c.html#a32a3cf3d9dd914f5aeeca5423c157934":[2,0,3,1,4,0],
+"gphoto2-port-result_8c.html#a42cb93c9a0e2ada0716ab6e89884f450":[2,0,3,1,4,7],
+"gphoto2-port-result_8c.html#a5f80e8482ab93869489531a8c7ce7006":[2,0,3,1,4,6],
+"gphoto2-port-result_8c.html#a75278405e7f034d2b1af80bfd94675fe":[2,0,3,1,4,5],
+"gphoto2-port-result_8c.html#a83b8be0887dede025766d25e2bb884c6":[2,0,3,1,4,4],
+"gphoto2-port-result_8c.html#ad24abc7110e1bdf384dc2ef2b63e5d07":[2,0,3,1,4,3],
+"gphoto2-port-result_8c.html#add6dfc1077058ff26d79cdb18099d58a":[2,0,3,1,4,1],
+"gphoto2-port-result_8h.html":[2,0,3,0,4],
+"gphoto2-port-result_8h.html#a1176f08c37f885d07b7682c0e53e8f42":[2,0,3,0,4,12],
+"gphoto2-port-result_8h.html#a2c013d68afcf5fa7e7452f757d463cf8":[2,0,3,0,4,2],
+"gphoto2-port-result_8h.html#a3d7d0cbb390f931e72a3b67c999a9183":[2,0,3,0,4,17],
+"gphoto2-port-result_8h.html#a42cb93c9a0e2ada0716ab6e89884f450":[2,0,3,0,4,22],
+"gphoto2-port-result_8h.html#a4d0d4c4c5c4b402da6159beb9831e0ce":[2,0,3,0,4,7],
+"gphoto2-port-result_8h.html#a503f642aca99f5001d85af2c1c3805ae":[2,0,3,0,4,4],
+"gphoto2-port-result_8h.html#a560d29bd042a83bdd6a87a5f3ffbcff4":[2,0,3,0,4,21],
+"gphoto2-port-result_8h.html#a571981fd142a047c1c259edeb287bd6a":[2,0,3,0,4,3],
+"gphoto2-port-result_8h.html#a67e09cf03a3ecbf9f8b52c93285cafaa":[2,0,3,0,4,6],
+"gphoto2-port-result_8h.html#a6a1a6e9b5c66257e1531eb20163ac675":[2,0,3,0,4,11],
+"gphoto2-port-result_8h.html#a7f606bc9a9ee8706ae77e2cc1c9bac19":[2,0,3,0,4,10],
+"gphoto2-port-result_8h.html#a91262711afe809d3eb12e370e8d79c09":[2,0,3,0,4,9],
+"gphoto2-port-result_8h.html#a92629507f0c8525ad8c042a733afd205":[2,0,3,0,4,19],
+"gphoto2-port-result_8h.html#a9af64fa5b5b5ff253cb1a8a39b130241":[2,0,3,0,4,8],
+"gphoto2-port-result_8h.html#aab604085d1124f2a688ac5a91423e9a8":[2,0,3,0,4,18],
+"gphoto2-port-result_8h.html#abd63939fa5eac99160d09a664d3f84aa":[2,0,3,0,4,15],
+"gphoto2-port-result_8h.html#ac28fe84223a56601b56a4953a8673e6c":[2,0,3,0,4,5],
+"gphoto2-port-result_8h.html#ad59062d61d227d96e614fda1e9171bb8":[2,0,3,0,4,1],
+"gphoto2-port-result_8h.html#ad620272923e042e85713b755783f7c07":[2,0,3,0,4,13],
+"gphoto2-port-result_8h.html#adbafb7248a8e2dd2b86118f227a73124":[2,0,3,0,4,16],
+"gphoto2-port-result_8h.html#ae235fa7ee045ef1d14f76c7e3c13fb69":[2,0,3,0,4,0],
+"gphoto2-port-result_8h.html#af56f93684bc8145a14a17d68ea20d589":[2,0,3,0,4,20],
+"gphoto2-port-result_8h.html#afd4a48ebc75390ed40bdf4b5cc30b258":[2,0,3,0,4,14],
+"gphoto2-port-result_8h_source.html":[2,0,3,0,4],
+"gphoto2-port-version_8c.html":[2,0,3,1,5],
+"gphoto2-port-version_8c.html#a293e53d10075f8c09b39325d8e54be43":[2,0,3,1,5,0],
+"gphoto2-port-version_8h.html":[2,0,3,0,5]
 };
