@@ -1,19 +1,19 @@
-/* A Bison parser, made by GNU Bison 2.5.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison interface for Yacc-like parsers in C
-   
-      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
-   
+
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
@@ -26,71 +26,76 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-   
+
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
+#ifndef YY_YY_DDB_TXT_TAB_H_INCLUDED
+# define YY_YY_DDB_TXT_TAB_H_INCLUDED
+/* Debug traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 0
+#endif
+#if YYDEBUG
+extern int yydebug;
+#endif
 
-/* Tokens.  */
+/* Token type.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     TOK_SEP = 258,
-     TOK_COMMA = 259,
-     TOK_WHITESPACE = 260,
-     TOK_NEWLINE = 261,
-     TOK_NUMBER = 262,
-     TOK_STRING = 263,
-     TOK_INTERFACE = 264,
-     TOK_DRIVER = 265,
-     TOK_DEVICE = 266,
-     TOK_BEGIN = 267,
-     TOK_END = 268,
-     TOK_SERIAL = 269,
-     TOK_SPEEDS = 270,
-     TOK_USB = 271,
-     TOK_PRODUCT = 272,
-     TOK_VENDOR = 273,
-     TOK_CLASS = 274,
-     TOK_SUBCLASS = 275,
-     TOK_PROTOCOL = 276,
-     TOK_DISK = 277,
-     TOK_PTPIP = 278,
-     TOK_DEVICE_TYPE = 279,
-     TOK_DRIVER_STATUS = 280,
-     TOK_OPERATIONS = 281,
-     TOK_FILE_OPERATIONS = 282,
-     TOK_FOLDER_OPERATIONS = 283,
-     TOK_DRIVER_OPTIONS = 284,
-     TOK_OPTION = 285,
-     VAL_FLAG = 286
-   };
+  enum yytokentype
+  {
+    TOK_SEP = 258,
+    TOK_COMMA = 259,
+    TOK_WHITESPACE = 260,
+    TOK_NEWLINE = 261,
+    TOK_NUMBER = 262,
+    TOK_STRING = 263,
+    TOK_INTERFACE = 264,
+    TOK_DRIVER = 265,
+    TOK_DEVICE = 266,
+    TOK_BEGIN = 267,
+    TOK_END = 268,
+    TOK_SERIAL = 269,
+    TOK_SPEEDS = 270,
+    TOK_USB = 271,
+    TOK_PRODUCT = 272,
+    TOK_VENDOR = 273,
+    TOK_CLASS = 274,
+    TOK_SUBCLASS = 275,
+    TOK_PROTOCOL = 276,
+    TOK_DISK = 277,
+    TOK_PTPIP = 278,
+    TOK_DEVICE_TYPE = 279,
+    TOK_DRIVER_STATUS = 280,
+    TOK_OPERATIONS = 281,
+    TOK_FILE_OPERATIONS = 282,
+    TOK_FOLDER_OPERATIONS = 283,
+    TOK_DRIVER_OPTIONS = 284,
+    TOK_OPTION = 285,
+    VAL_FLAG = 286
+  };
 #endif
 
+/* Value type.  */
 
-
-#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-
-# define yystype YYSTYPE /* obsolescent; will be withdrawn */
-# define YYSTYPE_IS_DECLARED 1
-#endif
-
-extern YYSTYPE yylval;
-
+/* Location type.  */
 #if ! defined YYLTYPE && ! defined YYLTYPE_IS_DECLARED
-typedef struct YYLTYPE
+typedef struct YYLTYPE YYLTYPE;
+struct YYLTYPE
 {
   int first_line;
   int first_column;
   int last_line;
   int last_column;
-} YYLTYPE;
-# define yyltype YYLTYPE /* obsolescent; will be withdrawn */
+};
 # define YYLTYPE_IS_DECLARED 1
 # define YYLTYPE_IS_TRIVIAL 1
 #endif
 
-extern YYLTYPE yylloc;
 
+extern YYSTYPE yylval;
+extern YYLTYPE yylloc;
+int yyparse (char const *file_name, CameraAbilitiesList *al);
+
+#endif /* !YY_YY_DDB_TXT_TAB_H_INCLUDED  */
